*! version 1.0.2  17jan2006  by Marc Muendler  muendler@ucsd.edu

capture mkdir "tex/desc"
capture mkdir "tex/desc/wagediffs"

clear
set memory 500m
set matsize 400
set more off

cd "$rootslct"

tempfile wdi cntrgrpbem concnace homswe98 cntrgrp_med_wage_98

* Country group resetting
capture program drop countrygrp_bem
program define countrygrp_bem
  * Apply BEM cntrybemgrp definitions
  /*-----------------------
   WEU: EMU (3), OWE (6);
   OIN: OIN (5);
   CEE: CEE (2); 
   DEV: APC (1), ODV (4) and RCA (7)
   --------------------------------------------*/
  tab cntrygrp_bem
  gen str3 cntrybemgrp = "CEE" if cntrygrp_bem=="CEE"
  replace  cntrybemgrp = "DEV" if cntrygrp_bem=="APC" | cntrygrp_bem=="ODV" | cntrygrp_bem=="OTR" | cntrygrp_bem=="RCA"
  replace  cntrybemgrp = "OIN" if cntrygrp_bem=="OIN"
  replace  cntrybemgrp = "WEU" if cntrygrp_bem=="EMU" | cntrygrp_bem=="OWE"
  label var cntrybemgrp "Country group BEM"
  rename cntrybemgrp _cntrybemgrp
  encode _cntrybemgrp, gen(cntrybemgrp) label(cntrybem)
  drop _cntrybemgrp
end


/* External data preperation  */
/*----------------------------*/

use "$root/countries/extdata-deflated", clear
keep if year==1999
keep country population
sort country
save `wdi'

use "$root/conc/cntry2bemgrp", clear
rename bubakey country
sort country
compress
save `cntrgrpbem'

use "$root/conc/sector-conc-nace", clear
sort nace11_code
compress
save `concnace'


/*------------------------------*/
/* Construct wage differentials */
/*------------------------------*/

* German wage level 1998
*-----------------------
use "$root/wages/swewages", clear
rename bubakey country
drop ln_wage_eur
keep if country==0
rename wage_eur home_wage_par
label var home_wage_par "Swedish MNE wage 1998"
gen int year = 1998
sort year
save `homswe98'

* Regional Swedish wages 1998 (used for 1996 and 2000)
*-----------------------------------------------------
use "$root/wages/swewages", clear
rename bubakey country
rename wage_eur cntr_wage
label var cntr_wage "Swedish MNE wage 1998"
drop if cntr_wage==.
sort country 
merge country using `wdi', nokeep
tab _merge
list country population cntr_wage if _merge==1 /* _merge==1 is Germany */
drop if country==0
drop _merge
sort country 
merge country using `cntrgrpbem' 
tab _merge
keep if _merge==3
drop _merge
countrygrp_bem
collapse (mean) cntr_wage [pw=population], by(cntrybemgrp) fast
rename cntr_wage cntrgrp_wage
label var cntrgrp_wage "Regional Swedish MNE wage 1998"
gen int year = 1998
sort year
merge year using `homswe98', nokeep
drop year _m
sort cntrybemgrp
save `cntrgrp_med_wage_98'


* Wage differential 1998 (used for 1996 and 2000)
*------------------------------------------------
use "$root/wages/destatis-gearn-defl", clear
keep if year==1998
drop agearn year
rename nace11 nace1
* replace missing with mean aggregate sector wage
gen byte _aggsec = int(nace1/10)
egen _agearn = mean(agearn), by(_aggsec)
replace agearn = _agearn if agearn==.
drop _*
* merge in countries
qui count
local obs = `r(N)'
expand 4
sort nace1
gen cntrybemgrp = _n - int(_n/4-.1)*4
sort cntrybemgrp
merge cntrybemgrp using `cntrgrp_med_wage_98'
tab _merge
drop _merge
* wagediffs and German ln wages
egen _agearn_avg = mean(agearn_med)
replace agearn_med = (home_wage_par / _agearn_avg) * agearn_med
rename agearn_med agearn_swe
label var agearn_swe "Sector wage (@ Swedish level)"
gen wagediff=cntrgrp_wage/agearn_swe
gen swediff =cntrgrp_wage/home_wage_par
label var wagediff "cntrgrp_wage/agearn_swe"
label var swediff  "cntrgrp_wage/home_w"
gen ln_wagediff=ln(wagediff)
gen ln_swediff=ln(wagediff)
label var ln_wagediff "ln(cntrgrp_wage/agearn_swe)"
label var ln_swediff "ln(cntrgrp_wage/home_w)"
local i 0
foreach var in wagediff ln_wagediff swediff ln_swediff {
  local i = `i' + 1
  local lbl`i' : variable label `var'
  }
replace agearn_swe = ln(agearn_swe)
rename agearn_swe w_HOM
label var w_HOM "ln Sector wage (@ Swedish level)"
keep nace1 cntrybemgrp wagediff ln_wagediff swediff ln_swediff w_HOM
preserve
  gen year=${selyear}
  sort year cntrybemgrp nace1
  save ${bef_reshape_${selyear}}
restore
reshape wide wagediff ln_wagediff swediff ln_swediff, i(nace1 w_HOM) j(cntrybemgrp)
local x=0
foreach name in $regagg {
  local x=`x'+1
  local i 0
  foreach var in wagediff ln_wagediff swediff ln_swediff {
    local i = `i' + 1
    rename `var'`x' `var'_`name' 
    label var `var'_`name' "`lbl`i'' `name'"
    }
  }
sort nace1
save ${wage_diff_${tlogyear}}
save ${wage_diff_${selyear}}
* aggregate reporting with table
rename nace1 nace11_code
sort nace11_code
merge nace11_code using "$root/conc/nace2bem", nokeep
collapse (mean) wagediff* swediff*, by(sec_bem) fast
keep sec_bem wagediff* swediff*
preserve 
  tempfile appndsel
  keep sec_bem swediff*
  keep in 1
  foreach reg in $regagg {
    rename swediff_`reg' wagediff_`reg'
    }
  replace sec_bem = 0
  save `appndsel'
restore
keep sec_bem wagediff*
append using `appndsel'
label define secbem 0 "Country-wide Swedish MNE wage", modify
rename sec_bem _rowname
save "tex/desc/wagediffs/diffsger98-$waglvl", replace
* matload diffsger98, p(tex/desc/wagediffs) over dropall missing(.)
qui do "$root/conc/secbem.do"
