*! version 1.2.9  14nov2006  by Marc Muendler muendler@ucsd.edu

/* Varcov correction assumes that selection equations have constant */
/* Selection equation assumed to have constant as last regressor */
/* Varcov correction assumes that sureg equations do not have constant (add a regressor called ones if constant needed) */
/* Sure equation assumed to have Mills ratio as last regressor */
/* Regional wages are supposed to be first (5) regressors in SUR equations */

clear
set memory 400m
set matsize 800
set more off
capture log close

cd "$rootslct"

log using "logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-nonparam-relaxed.log", replace

mat drop _all

local maxiter $maxiter
local usexvar $usexvar  /* selection regressor varlist to be used for selectivity correction in sureg */
local maxvars 4  /* longest used selection regressor varlist */
local surxno 15  /* number of SURE regressors per equation (excluding noFDI indicators, excluding adj. constant/ones and excluding propensity scores) */

adopath + "$root/%stata/ado"

#delimit ;


/* define X-equation restrictions */
/*--------------------------------*/

* constraint define  1 [sCE]cf_wHO = [sHO]cf_wCE;
  constraint define  2 [sCE]cf_wDE = [sDE]cf_wCE;
  constraint define  3 [sCE]cf_wOI = [sOI]cf_wCE;
  constraint define  4 [sCE]cf_wWE = [sWE]cf_wCE;
* constraint define  5 [sDE]cf_wHO = [sHO]cf_wDE;
  constraint define  6 [sDE]cf_wOI = [sOI]cf_wDE;
  constraint define  7 [sDE]cf_wWE = [sWE]cf_wDE;
* constraint define  8 [sOI]cf_wHO = [sHO]cf_wOI;
  constraint define  9 [sOI]cf_wWE = [sWE]cf_wOI;
* constraint define 10 [sWE]cf_wHO = [sHO]cf_wWE;
* constraint define 11 [sHO]cf_wHO + [sHO]cf_wCE + [sHO]cf_wDE + [sHO]cf_wOI + [sHO]cf_wWE = 0;
  constraint define 12 [sCE]cf_wHO + [sCE]cf_wCE + [sCE]cf_wDE + [sCE]cf_wOI + [sCE]cf_wWE = 0;
  constraint define 13 [sDE]cf_wHO + [sDE]cf_wCE + [sDE]cf_wDE + [sDE]cf_wOI + [sDE]cf_wWE = 0;
  constraint define 14 [sOI]cf_wHO + [sOI]cf_wCE + [sOI]cf_wDE + [sOI]cf_wOI + [sOI]cf_wWE = 0;
  constraint define 15 [sWE]cf_wHO + [sWE]cf_wCE + [sWE]cf_wDE + [sWE]cf_wOI + [sWE]cf_wWE = 0;

/* With 5 regions, there are (5*5-5)/2=10 symmetry restrictions in principle. 
   However, one equation drops due to further cross-equation constraints, 
   only 6 of the symmetry restrictions are needed.
   Similarly, only 4 of the 5 restrictions on wage parameter sums are needed. */


/* variable sets for selection estimation */
/*----------------------------------------*/

do $dp/!varsets-np.do;

/* nonparametric base variables for sureg estimation */
/*---------------------------------------------------*/

local pscores "pscCE pscDE pscOI pscWE"; /* first-order terms */
local regord = trim(subinstr("`pscores'","psc","",.));
local pscser2 ""; /* second-order terms */
local cnt 0;
foreach reg in `regord' {;
  local cnt = `cnt' + 1;
  local r2dg = substr("`reg'",1,2);
  tokenize `pscores';
  local pscno : word count `pscores';
  forvalues i = `cnt'/`pscno' {;
    local addtrm "``i''_`r2dg'";
    local pscser2 "`pscser2' `addtrm'";
    };
  };
local pscser3 ""; /* third-order terms */
local cnt 1;
local strt 0;
foreach reg in `regord' {;
  local strt = `strt' + `cnt';
  local r2dg = substr("`reg'",1,2);
  tokenize `pscser2';
  local pscno : word count `pscser2';
  local cnt 0;
  forvalues i = `strt'/`pscno' {;
    * if length(subinstr("``i''",substr("``i''",-2,2),"",.))==4 {; /* operate only on square terms, not in general on interaction terms */
    if substr("``i''",-2,2)=="`r2dg'"  local cnt = `cnt' + 1;
    local addtrm "``i''_`r2dg'";
    local pscser3 "`pscser3' `addtrm'";
    * };
    };
  };
local pscser "`pscores'`pscser2'`pscser3'";
disp "`pscser'";
local pscno : word count `pscser';
disp "`pscno'";


/* data */
/*------*/

tempfile popinfo;
use "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff", clear;
keep if year==2000;
keep mneid i*;  /* do not update sample-specific nofdi indicators for translog */
sort mneid;
compress;
save `popinfo';

local howmany = subinstr("$howmany","0","",.);  /* omnipresent MNE no permitted */
foreach usemissg in `howmany' {; /* begin `usemissg' loop */

capture mkdir "$rootslct/tex/v3npr";
capture mkdir "$rootslct/estmat/v3npr";
capture mkdir "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/byreg";
capture mkdir "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'";

use "$rootslct/Xdata/mneid-outwfdi-ustan-2000-translog-$waglvl-pt$par-af$aff", clear;
drop naff;

foreach var in s w t k {;
  gen double cf_`var' = cf * `var';
  };
drop l;
replace cntrybemgrp=(substr(cntrybemgrp,1,2));
rename cf_s y;

if `usemissg' == 0 {;
* keep usemissg observations as they are;
    drop nofdi;
    /* s:costShare y:Labor w:Wage t:Turnover("Output") k:Capital */
    reshape wide s w t k y cf_w cf_t cf_k cf, i(mneid) j(cntrybemgrp) string;
    };

if `usemissg' == 1 {;
* construct stacked system;
    foreach var in s w t k y cf_w cf_t cf_k cf {;
        replace `var'=0 if `var'==.;
       };
    reshape wide s w t k y cf_w cf_t cf_k cf nofdi, i(mneid) j(cntrybemgrp) string;
    };

if `usemissg' == 2 {;
* construct stacked system;
    foreach var in s w t k y cf_w cf_t cf_k cf {;
        replace `var'=0 if `var'==.;
       };
    reshape wide s w t k y cf_w cf_t cf_k cf nofdi, i(mneid) j(cntrybemgrp) string;
   * set regressors to zero in equations where MNE is absent;
    preserve;
      foreach reg in HOM $regagg {;
        tempfile eq`reg';
        local r2dg = substr("`reg'",1,2);
        restore, preserve;
        keep mneid y`r2dg' cf_w* cf_t* cf_k* nofdi* cf*;
        foreach eqreg in HOM $regagg {;
          local eqr2dg = substr("`eqreg'",1,2);
          foreach var in cf`eqr2dg' cf_w`eqr2dg' cf_t`eqr2dg' cf_k`eqr2dg' nofdi`eqr2dg' {;
            qui replace `var' = 0 if y`r2dg'==0; /* nofdi`r2dg'==1 */
            rename `var' `var'_eq`r2dg';
            };
          };
        order mneid cf_w??_eq`r2dg' cf_t??_eq`r2dg' cf_k??_eq`r2dg' nofdi??_eq`r2dg' cf`r2dg'_eq`r2dg';
        keep mneid cf_w??_eq`r2dg' cf_t??_eq`r2dg' cf_k??_eq`r2dg' nofdi??_eq`r2dg' cf`r2dg'_eq`r2dg';
        sort mneid;
        save `eq`reg'';
        };
    restore;
    foreach reg in HOM $regagg {;
      sort mneid;
      merge mneid using `eq`reg'';
      qui count if _m~=3;
      if `r(N)'>0 {;
        disp as err "bad match in `reg'";
        error;
        };
      drop _m;
      };
    drop nofdiCE_eqCE nofdiDE_eqDE nofdiOI_eqOI nofdiWE_eqWE;
  }; /* close if `usemissg' == 2 */

sort mneid;
merge mneid using "$rootslct/Xdata/mvprobit-outwfdi-ustan-2000-$waglvl-pt$par-af$aff";
tab _merge;
drop _merge;
sort mneid;

* competitor regressors;
merge mneid using "$rootslct/Xdata/mneid-outwfdi-ustan-1996-costothr-$waglvl-pt$par-af$aff";
tab _merge;
foreach var in s k t l w wb {;
  foreach reg in $regagg {;
    qui gen double _MN`var'_`reg' = `var'_othr_`reg' if _m==2; /* market average (mneid==0 in using data) */
    qui egen double _rpl_`var'_`reg' = max(_MN`var'_`reg');
    qui replace `var'_othr_`reg' = _rpl_`var'_`reg' if `var'_othr_`reg'==.; /* replace missing competitor info with market average (mneid==0 in using data) */
    drop _MN`var'_`reg' _rpl_`var'_`reg';
    };
  };
drop if mneid==0;
drop _merge;
sort mneid;
merge mneid using "$rootslct/Xdata/mneid-outwfdi-ustan-1996-wwlocvars-pt$par-af$aff";
* following code only used when "ustan-1996-locvars" loaded (not "-wwlocvars")
* foreach reg in $regagg {;
*   local r2dg = substr("`reg'",1,2);
*   foreach var in employmt ln_dist ln_gdp ln_gdp_cap ln_consum_exp ln_cons_cap lh99_1 lh99_2 {; 
*     qui gen double _MN`var' = `var'_othr_`reg' if _m==2; /* market average (mneid==0 in using data) */
*     qui egen double _rpl_`var' = max(_MN`var');
*     qui replace `var'_othr_`reg' = _rpl_`var' if `var'_othr_`reg'==.;  /* replace missing competitor info with market average (mneid==0 in using data) */
*     rename `var'_othr_`reg' `var'_othr_`r2dg'; 
*     drop _MN`var' _rpl_`var';
*     };
*   };
drop if mneid==0;
tab _merge;
drop _merge;
sort mneid;

* parent level regressors;
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  foreach year in 1996 2000 {;
    local yr = substr("`year'",-2,2);
    drop chosen_`reg'_`year';  /* drop sample presence indicators, use population indicators below */
    rename ln_wagediff_`reg'_`year' ln_wdiff_`r2dg'`yr';
    };
  };
foreach year in 1996 2000 {;
  local yr = substr("`year'",-2,2);
  rename ln_inter_`year' ln_inter`yr';
  foreach var in ln_employmt ln_exports ln_fixdasst ln_assettot ln_profits ln_turnover ln_equity ln_liab ln_caplabrat profeqtyrat {;
    rename `var'_par_`year' `var'`yr';
    };
  };
drop w_HOM_2000 w_othr_HOM ln_wdiff*; rename w_HOM_1996 w_HOM;
replace w_HOM = exp(w_HOM);  /* plain wage */
local lbl : variable label w_HOM;
local lbl = subinstr("`lbl'","ln ","",.);
label var w_HOM "`lbl'";

* wage variable redefinitions: all wages for selection regression in 1,000 EUR;
replace w_HOM = w_HOM/1000;
local lbl : variable label w_HOM;
local lbl = "`lbl' [Thd EUR]";
label var w_HOM "`lbl'";
foreach reg in $regagg {;
  replace w_othr_`reg' = w_othr_`reg'/1000;
  local lbl : variable label w_othr_`reg';
  local lbl = "`lbl' [Thd EUR]";
  label var w_othr_`reg' "`lbl'";
  };

* wage variable redefinitions: all wages for selection regression not in logs (plain);
* replace w_HOM = log(w_HOM);
* local lbl : variable label w_HOM;
* local lbl = "ln `lbl'";
* label var w_HOM "`lbl'";
* foreach reg in $regagg {;
*   replace w_othr_`reg' = log(w_othr_`reg');
*   local lbl : variable label w_othr_`reg';
*   local lbl = "ln `lbl'";
*   label var w_othr_`reg' "`lbl'";
*   };

* regional presence indicators and affiliate counts from population information;
gen byte iHO00 = 1;  /* Permanent presence in Home */
label var iHO00 "Presence HOM 00";
sort mneid;
merge mneid using `popinfo', nokeep;
tab _m;
drop _m;

* matrices for marginal effects of wages on selection and of propensity scores on labor demand;
mat pscdlnw = J(4,5,.);
mat suredps = J(4,4,.);
matrix rownames pscdlnw = $regagg;
matrix rownames suredps = $regagg;
matrix colnames pscdlnw = HOM $regagg;
matrix colnames suredps = $regagg;
local rownames : rowfullnames pscdlnw;
local rownum : word count `rownames';
tokenize `rownames';
forvalues rowi = 1/`rownum' {;
  local rownew = "i_" + substr("``rowi''",-3,3);
  matname pscdlnw `rownew', rows(`rowi') explicit;
  local rownew = "y_" + substr("``rowi''",-3,3);
  matname suredps `rownew', rows(`rowi') explicit;
  };
local colnames : colfullnames pscdlnw;
local colnum : word count `colnames';
tokenize `colnames';
forvalues coli = 1/`colnum' {;
  local colnew = "w_" + substr("``coli''",-3,3);
  matname pscdlnw `colnew', columns(`coli') explicit;
  };
local colnames : colfullnames suredps;
local colnum : word count `colnames';
tokenize `colnames';
forvalues coli = 1/`colnum' {;
  local colnew = "ps_" + substr("``coli''",-3,3);
  matname suredps `colnew', columns(`coli') explicit;
  };

* Create selection polynomial regressors;
tokenize ${selser};
local selno : word count ${selser};
forvalues i = 1/`selno' {;
  local varname "``i''";
  local preptrm = subinstr(subinstr("``i''","w_","",.),"_"," ",.);
  * first-order terms;
  local var1 :  word 1 of `preptrm';
  if lower("`var1'")~="`var1'"  local var1 "w_othr_`var1'";
  else  local var1 "ln_`var1'";
  if substr("`var1'",-3,3)=="HOM"  local var1 = subinstr("`var1'","_othr","",.);
  * second-order terms;
  local var2 :  word 2 of `preptrm';
  if lower("`var2'")~="`var2'" & length("`var2'")>0  local var2 "w_othr_`var2'";
  if lower("`var2'")=="`var2'" & length("`var2'")>0  local var2 "ln_`var2'";
  if length("`var2'")>0  local var2 " * `var2'";
  if substr("`var2'",-3,3)=="HOM"  local var2 = subinstr("`var2'","_othr","",.);
  * third-order terms;
  local var3 :  word 3 of `preptrm';
  if lower("`var3'")~="`var3'" & length("`var3'")>0  local var3 "w_othr_`var3'";
  if lower("`var3'")=="`var3'" & length("`var3'")>0  local var3 "ln_`var3'";
  if length("`var3'")>0  local var3 " * `var3'";
  if substr("`var3'",-3,3)=="HOM"  local var3 = subinstr("`var3'","_othr","",.);
  if length("`var2'")>0 {;
    qui gen double `varname' = `var1'`var2'`var3';
    label var `varname' "(`varname')";
    };
  };
  * sector dummies;
  qui summ sec1_bem;
  local minsec = `r(min)'+1;
  local maxsec = `r(max)';
  local dumlst = "_Isec1_bem_`minsec'";
  local secdum = "_b[_Isec1_bem_`minsec']*_Isec1_bem_`minsec'";
  local secavgdum = "_b[_Isec1_bem_`minsec']*_MN_Isec1_bem_`minsec'";
  local minsec = `minsec' + 1;
  forvalues j = `minsec'/`maxsec' {;
    local dumlst "`dumlst' _Isec1_bem_`j'";
    local secdum "`secdum' + _b[_Isec1_bem_`j']*_Isec1_bem_`j'";
    local secavgdum "`secavgdum' + _b[_Isec1_bem_`j']*_MN_Isec1_bem_`j'";
    };
      

/* first step: non-parametric selection estimation */
/*-------------------------------------------------*/

foreach reg in $regagg {;
  forvalues xvars = `maxvars'(-1)0 {;
    local r2dg = substr("`reg'",1,2);
    tempname chk;

    * selection regressions with sector dummies;
    xi: regress i`r2dg'00 iCE96 iDE96 iOI96 iWE96 ${parnp_`xvars'} i.sec1;
    capture local chk = rowsof(selreg`r2dg'_b);
    if _rc==111 {;
      est2vec selreg`r2dg', vars(iCE96 iDE96 iOI96 iWE96 ${parnp_`maxvars'} _Isec1_bem_1 _Isec1_bem_2 _Isec1_bem_3 _Isec1_bem_4 _Isec1_bem_5 _Isec1_bem_6 _Isec1_bem_7 _Isec1_bem_8 _Isec1_bem_9 _cons) e(N ll F chi2 df_m r2 r2_p) name(`r2dg'`xvars'i);
      * est2vec selreg`r2dg', r(entry_chi2 entry_df entry_p exit_chi2 exit_df exit_p hyst_chi2 hyst_df hyst_p) name(`r2dg'`xvars'i);
      };
    else {;
      est2vec selreg`r2dg', addto(selreg`r2dg') name(`r2dg'`xvars'i);
      * est2vec selreg`r2dg', raddto(selreg`r2dg') name(`r2dg'`xvars'i);
      };
    * tests for joint significance by region;
    tokenize ${parnp_`xvars'};
    local regrno : word count ${parnp_`xvars'};
    foreach tstreg in HOM $regagg {;
      local t2dg = substr("`tstreg'",1,2);
      local tstlst`t2dg' = "";
      forvalues i = 1/`regrno' {;
        if subinstr("``i''","`tstreg'","",.)~="``i''" & substr("``i''",1,2)=="w_"  local tstlst`t2dg' "`tstlst`t2dg'' ``i''";
        };
      * disp in yellow "`tstlst`t2dg''";
      if "`tstlst`t2dg''"~=""  test `tstlst`t2dg'';
      if "`tstlst`t2dg''"~=""  est2vec r`t2dg', r(F df p) name(`r2dg'`xvars'i);
      else {;
        mat r`t2dg'_r = J(3,1,.);
        matrix rownames r`t2dg'_r = F df p;
        };
    };
    capture mat selreg`r2dg'_r = selreg`r2dg'_r , ( J(9,1,.) \ rHO_r \ rCE_r \ rDE_r \ rOI_r \ rWE_r );
    if _rc {;
      mat selreg`r2dg'_r = ( J(9,1,.) \ rHO_r \ rCE_r \ rDE_r \ rOI_r \ rWE_r );
      };
    local matcol = colsof(selreg`r2dg'_r);
    matname selreg`r2dg'_r `r2dg'`xvars'i, columns(`matcol') explicit;
    mat drop rHO_r rCE_r rDE_r rOI_r rWE_r;

    * selection regressions without sector dummies (used for translog);
    * disp "parnp_`xvars': ${parnp_`xvars'}";
    regress i`r2dg'00 iCE96 iDE96 iOI96 iWE96 ${parnp_`xvars'};
    capture local chk = rowsof(selreg`r2dg'_b);
    if _rc==111 {;
      est2vec selreg`r2dg', vars(iCE96 iDE96 iOI96 iWE96 ${parnp_`maxvars'} _Isec1_bem_1 _Isec1_bem_2 _Isec1_bem_3 _Isec1_bem_4 _Isec1_bem_5 _Isec1_bem_6 _Isec1_bem_7 _Isec1_bem_8 _Isec1_bem_9 _cons) e(N ll F chi2 df_m r2 r2_p) name(`r2dg'`xvars');
      * est2vec selreg`r2dg', r(entry_chi2 entry_df entry_p exit_chi2 exit_df exit_p hyst_chi2 hyst_df hyst_p) name(`r2dg'`xvars');
      };
    else {;
      est2vec selreg`r2dg', addto(selreg`r2dg') name(`r2dg'`xvars');
      * est2vec selreg`r2dg', raddto(selreg`r2dg') name(`r2dg'`xvars');
      };
    * tests for hysteresis;
    test - _cons = 0; 
    est2vec r1, r(F df p) name(`r2dg'`xvars');
    test i`r2dg'96 + _cons = 0; 
    est2vec r2, r(F df p) name(`r2dg'`xvars');
    test - i`r2dg'96 = 0; 
    est2vec r3, r(F df p) name(`r2dg'`xvars');
    * tests for joint significance by region;
    tokenize ${parnp_`xvars'};
    local regrno : word count ${parnp_`xvars'};
    foreach tstreg in HOM $regagg {;
      local t2dg = substr("`tstreg'",1,2);
      local tstlst`t2dg' = "";
      forvalues i = 1/`regrno' {;
        if subinstr("``i''","`tstreg'","",.)~="``i''" & substr("``i''",1,2)=="w_"  local tstlst`t2dg' "`tstlst`t2dg'' ``i''";
        };
      * disp in yellow "`tstlst`t2dg''";
      if "`tstlst`t2dg''"~=""  test `tstlst`t2dg'';
      if "`tstlst`t2dg''"~=""  est2vec r`t2dg', r(F df p) name(`r2dg'`xvars');
      else {;
        mat r`t2dg'_r = J(3,1,.);
        matrix rownames r`t2dg'_r = F df p;
        };
    };
    capture mat selreg`r2dg'_r = selreg`r2dg'_r , ( r1_r \ r2_r \ r3_r \ rHO_r \ rCE_r \ rDE_r \ rOI_r \ rWE_r );
    if _rc {;
      mat selreg`r2dg'_r = ( r1_r \ r2_r \ r3_r \ rHO_r \ rCE_r \ rDE_r \ rOI_r \ rWE_r );
      };
    matrix rownames selreg`r2dg'_r = entry_F entry_df entry_p exit_F exit_df exit_p hyst_F hyst_df hyst_p wHOM_F wHOM_df wHOM_p wCEE_F wCEE_df wCEE_p wDEV_F wDEV_df wDEV_p wOIN_F wOIN_df wOIN_p wWEU_F wWEU_df wWEU_p;
    mat drop r1_r r2_r r3_r;
    mat drop rHO_r rCE_r rDE_r rOI_r rWE_r;

    * predict propensity scores from selection regressions without sector dummies;
    if `xvars' == `usexvar' {;   /* Only xvars `usexvar' used for second stage */
      predict double psc`r2dg', xb;
      label var psc`r2dg' "Propensity score `r2dg' (xvars `xvars')";
      * summ psc`r2dg';
    };

    * observation-specific predictions for extensive margins, selection part;
    if `xvars' == `usexvar' {;   /* only xvars `usexvar' used for second stage */
      tokenize ${parnp_`xvars'} iCE96 iDE96 iOI96 iWE96 `dumlst';
      local regrno : word count ${parnp_`xvars'} iCE96 iDE96 iOI96 iWE96 `dumlst';
      forvalues i = 1/`regrno' {;
        local varname = subinstr("_MN``i''","othr_","",.);
        qui egen double `varname' = mean(``i'') if e(sample);
        };
      * operate on: w_HOM w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU w_HOM_2 w_othr_CEE_2 w_othr_DEV_2 w_othr_OIN_2 w_othr_WEU_2;
      *        and  w_HOM_CEE w_HOM_DEV w_HOM_OIN w_HOM_WEU w_HOM_inter96 w_HOM_mktacc w_CEE_DEV w_CEE_OIN w_CEE_WEU w_CEE_inter96 w_CEE_mktacc w_DEV_OIN w_DEV_WEU w_DEV_inter96 w_DEV_mktacc w_OIN_WEU w_OIN_inter96 w_OIN_mktacc;
      *        etc.;

      * Evaluation of wage effects;
      tokenize ${parnp_`xvars'};
      local regrno : word count ${parnp_`xvars'};
      foreach wreg in HOM $regagg {;
        local predacc "_b[_cons]";  /* predicted poynomial terms, varying only by `wreg' wage (all other vars are sample means) */
        * local restavgacc "`secavgdum' + _b[iCE96]*_MNiCE96 + _b[iDE96]*_MNiDE96 + _b[iOI96]*_MNiOI96 + _b[iWE96]*_MNiWE96";  /* predicted remaining terms, not varying (sample means) */
        local restavgacc "_b[iCE96]*_MNiCE96 + _b[iDE96]*_MNiDE96 + _b[iOI96]*_MNiOI96 + _b[iWE96]*_MNiWE96";  /* predicted remaining terms, not varying (sample means) */
        * local restacc "`secdum' + _b[iCE96]*iCE96 + _b[iDE96]*iDE96 + _b[iOI96]*iOI96 + _b[iWE96]*iWE96";  /* predicted remaining terms, varying by all variables for standard error calculation */
        local restacc "_b[iCE96]*iCE96 + _b[iDE96]*iDE96 + _b[iOI96]*iOI96 + _b[iWE96]*iWE96";  /* predicted remaining terms, varying by all variables for standard error calculation */
        local matacc "0";  /* marginal effect of `wreg' wage */
        * local chkacc "`predacc' + `restacc'";  /* for consistency checks (disabled) */
        local w2dg = substr("`wreg'",1,2);
        local regvar = "w_othr_`wreg'";
        if "`wreg'"=="HOM"  local regvar = "w_`wreg'";
        forvalues i = 1/`regrno' {;
          if length(subinstr("``i''","`wreg'","",.)) < length("``i''") {;  /* wage variable appears in token: treat */
            if lower(subinstr("``i''","`wreg'","",.)) == subinstr("``i''","`wreg'","",.) & substr(subinstr("``i''","`wreg'","",.),-1,1)=="_" {;  /* only `wreg' terms appear in token */
              local predacc "`predacc' + _b[``i'']*``i''";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-3  local matacc "`matacc' + _b[``i'']";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-6  local matacc "`matacc' + 2*_b[``i'']*`regvar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-9  local matacc "`matacc' + 3*_b[``i'']*w_`wreg'_`wreg'";
              * local chkacc "`chkacc' + _b[``i'']*``i''";
              };
            else {; /* mixed `wreg' and other terms appear in token */
              local covar = "_MN" + subinstr(subinstr(subinstr(subinstr("``i''","`wreg'","",.),"__","_",.),"__","_",.),"othr_","",.);
              if substr("`covar'",-1,1)=="_"  local covar = substr("`covar'",1,length("`covar'")-1);
              if lower(subinstr("`covar'","_MN","",.))==subinstr("`covar'","_MN","",.) & length("`covar'")<=12  local covar = subinstr("`covar'","w_","ln_",.);
              if lower(subinstr("`covar'","_MN","",.))==subinstr("`covar'","_MN","",.) & length("`covar'") >12  local covar = subinstr("`covar'","w_","",.);
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-3  local predacc "`predacc' + _b[``i'']*`regvar'*`covar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-6  local predacc "`predacc' + _b[``i'']*w_`wreg'_`wreg'*`covar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-3  local matacc "`matacc' + _b[``i'']*`covar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-6  local matacc "`matacc' + 2*_b[``i'']*`regvar'*`covar'";
              * local chkacc "`chkacc' + _b[``i'']*``i''";
              };
            };
          if length(subinstr("``i''","`wreg'","",.)) == length("``i''") {;  /* wage variable does not appear in token: store for mean subtraction */
            local exclvar = subinstr("``i''","othr_","",.);
            local restavgacc "`restavgacc' + _b[``i'']*_MN`exclvar'";
            local restacc "`restacc' + _b[``i'']*``i''";
            * local chkacc "`chkacc' + _b[``i'']*``i''";
            };
          };
        * disp in yellow "`predacc'"; * disp in yellow "`restacc'"; * disp in yellow "`restavgacc'"; * disp in yellow "`matacc'";
        qui gen double dpsc`r2dg'dw`w2dg' = `predacc' + `restavgacc' if e(sample);
        * qui gen double __chkacc = `chkacc' if e(sample);
        * summ __chkacc psc`r2dg';  /* check identity */
        * drop __chkacc;
        qui gen double _mpsc`r2dg'w`w2dg' = `matacc' if e(sample);
        qui summ _mpsc`r2dg'w`w2dg', meanonly;
        mat pscdlnw[rownumb(pscdlnw,"i_`reg'"),colnumb(pscdlnw,"w_`wreg'")] = `r(mean)';
        * CIs from SE of prediction (default);
        * qui gen double dpsc`r2dg'dw`w2dg'_se = i`r2dg'00 - dpsc`r2dg'dw`w2dg' + `restavgacc' - `restacc' if e(sample); /* split gen command to shorten line */
        qui gen double dpsc`r2dg'dw`w2dg'_se = i`r2dg'00 - dpsc`r2dg'dw`w2dg' if e(sample);
        qui replace dpsc`r2dg'dw`w2dg'_se = dpsc`r2dg'dw`w2dg'_se + `restavgacc' if e(sample); 
        qui replace dpsc`r2dg'dw`w2dg'_se = dpsc`r2dg'dw`w2dg'_se - `restacc' if e(sample);
        qui gen double dpsc`r2dg'dw`w2dg'_lcl = dpsc`r2dg'dw`w2dg' - invttail(e(df_r),((100-${S_level})/200)) * dpsc`r2dg'dw`w2dg'_se if e(sample);
        qui gen double dpsc`r2dg'dw`w2dg'_ucl = dpsc`r2dg'dw`w2dg' + invttail(e(df_r),((100-${S_level})/200)) * dpsc`r2dg'dw`w2dg'_se if e(sample);
        label var dpsc`r2dg'dw`w2dg' "Wage w`w2dg' effect on selection i`r2dg'";
        label var dpsc`r2dg'dw`w2dg'_lcl "${S_level}% CI w`w2dg' eff on sel i`r2dg'";
        label var dpsc`r2dg'dw`w2dg'_ucl "${S_level}% CI w`w2dg' eff on sel i`r2dg'";
        * sort `regvar';
        * twoway connected dpsc`r2dg'dw`w2dg' dpsc`r2dg'dw`w2dg'_lcl dpsc`r2dg'dw`w2dg'_ucl `regvar';
        * twoway connected dpsc`r2dg'dw`w2dg' `regvar';
        drop dpsc`r2dg'dw`w2dg'_se;
        * drop _mpsc`r2dg'w`w2dg'; 
        }; /* close wreg loop */
      drop _MN*;
      };
    };  /* close xvars loop */
  };  /* close reg loop */

sort mneid;
disp in gr "Matrix of wage effects on FDI presence (usemissg: " in ye `usemissg' in gr ")";
mat list pscdlnw;

* Save data for bootstrap routine;
preserve;
  drop _* dpsc`r2dg'dw`w2dg'*;
  sort mneid;
  save "$rootslct/Xdata/mneid-forbstrap-$waglvl-pt$par-af$aff-cf-nonparam-relaxed", replace;
restore;

* Generate polynomial interaction terms for sureg regression;
foreach var of local pscser {;
  if length("`var'")>5 {;
    local term = subinstr("`var'","_","*psc",.);
    qui gen double `var' = `term';
    label var `var' "(`term' for sureg)";
    if `usemissg'==2 {;
      foreach eqreg in $regagg {;
        local eqr2dg = substr("`eqreg'",1,2);
        qui gen double `var'_eq`eqr2dg' = `var';
        qui replace `var'_eq`eqr2dg' = 0 if y`eqr2dg'==0; /* nofdi`eqr2dg'==1 */;
        };
      };
    };
  };

if `usemissg'==2 {;
  foreach var of local pscores {; /* var creation for `pscser' beyond `pscores' above */
    foreach eqreg in $regagg {;
      local eqr2dg = substr("`eqreg'",1,2);
      qui gen double `var'_eq`eqr2dg' = `var';
      qui replace `var'_eq`eqr2dg' = 0 if y`eqr2dg'==0; /* nofdi`eqr2dg'==1 */;
      };
    };
  tokenize `pscser';
  local num : word count `pscser';
  foreach eqreg in $regagg {;
    local eqr2dg = substr("`eqreg'",1,2);
    local pscser`eqr2dg' "";
    forvalues i = 1/`num' {;
      local pscser`eqr2dg' "`pscser`eqr2dg'' ``i''_eq`eqr2dg'";
      };
    };
  };


/* second step: seemingly unrelated regressions with nonparametric error terms */
/*-----------------------------------------------------------------------------*/

if `usemissg' == 0 {;
sureg (sCE: yCE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cfCE `pscser')
      (sDE: yDE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cfDE `pscser')
      (sOI: yOI = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cfOI `pscser')
      (sWE: yWE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cfWE `pscser')
      , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate(`maxiter');
*     (sHO: yHO = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cfHO `pscser'); /* left-out equation */
};

if `usemissg' == 1 {;
sureg (sCE: yCE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiDE nofdiOI nofdiWE cfCE `pscser')
      (sDE: yDE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiCE nofdiOI nofdiWE cfDE `pscser')
      (sOI: yOI = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiCE nofdiDE nofdiWE cfOI `pscser')
      (sWE: yWE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiCE nofdiDE nofdiOI cfWE `pscser')
      , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate(`maxiter');
*     (sHO: yHO = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiCE nofdiDE nofdiOI nofdiWE cfHO `pscser'); /* left-out equation */
};

if `usemissg' == 2 {;
sureg (sCE: yCE = cf_wHO_eqCE cf_wCE_eqCE cf_wDE_eqCE cf_wOI_eqCE cf_wWE_eqCE cf_tHO_eqCE cf_tCE_eqCE cf_tDE_eqCE cf_tOI_eqCE cf_tWE_eqCE cf_kHO_eqCE cf_kCE_eqCE cf_kDE_eqCE cf_kOI_eqCE cf_kWE_eqCE nofdiDE_eqCE nofdiOI_eqCE nofdiWE_eqCE cfCE_eqCE `pscserCE')
      (sDE: yDE = cf_wHO_eqDE cf_wCE_eqDE cf_wDE_eqDE cf_wOI_eqDE cf_wWE_eqDE cf_tHO_eqDE cf_tCE_eqDE cf_tDE_eqDE cf_tOI_eqDE cf_tWE_eqDE cf_kHO_eqDE cf_kCE_eqDE cf_kDE_eqDE cf_kOI_eqDE cf_kWE_eqDE nofdiCE_eqDE nofdiOI_eqDE nofdiWE_eqDE cfDE_eqDE `pscserDE')
      (sOI: yOI = cf_wHO_eqOI cf_wCE_eqOI cf_wDE_eqOI cf_wOI_eqOI cf_wWE_eqOI cf_tHO_eqOI cf_tCE_eqOI cf_tDE_eqOI cf_tOI_eqOI cf_tWE_eqOI cf_kHO_eqOI cf_kCE_eqOI cf_kDE_eqOI cf_kOI_eqOI cf_kWE_eqOI nofdiCE_eqOI nofdiDE_eqOI nofdiWE_eqOI cfOI_eqOI `pscserOI')
      (sWE: yWE = cf_wHO_eqWE cf_wCE_eqWE cf_wDE_eqWE cf_wOI_eqWE cf_wWE_eqWE cf_tHO_eqWE cf_tCE_eqWE cf_tDE_eqWE cf_tOI_eqWE cf_tWE_eqWE cf_kHO_eqWE cf_kCE_eqWE cf_kDE_eqWE cf_kOI_eqWE cf_kWE_eqWE nofdiCE_eqWE nofdiDE_eqWE nofdiOI_eqWE cfWE_eqWE `pscserWE')
      , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate(`maxiter');
*     (sHO: yHO = cf_wHO_eqHO cf_wCE_eqHO cf_wDE_eqHO cf_wOI_eqHO cf_wWE_eqHO cf_tHO_eqHO cf_tCE_eqHO cf_tDE_eqHO cf_tOI_eqHO cf_tWE_eqHO cf_kHO_eqHO cf_kCE_eqHO cf_kDE_eqHO cf_kOI_eqHO cf_kWE_eqHO nofdiCE_eqHO nofdiDE_eqHO nofdiOI_eqHO nofdiWE_eqHO cfHO_eqHO `pscserHO'); /* left-out equation */
};

* alternative, without nofdi indicators;
* if `usemissg' == 3 {;
* sureg (sCE: yCE = cf_wHO_eqCE cf_wCE_eqCE cf_wDE_eqCE cf_wOI_eqCE cf_wWE_eqCE cf_tHO_eqCE cf_tCE_eqCE cf_tDE_eqCE cf_tOI_eqCE cf_tWE_eqCE cf_kHO_eqCE cf_kCE_eqCE cf_kDE_eqCE cf_kOI_eqCE cf_kWE_eqCE cfCE_eqCE `pscserCE')
*       (sDE: yDE = cf_wHO_eqDE cf_wCE_eqDE cf_wDE_eqDE cf_wOI_eqDE cf_wWE_eqDE cf_tHO_eqDE cf_tCE_eqDE cf_tDE_eqDE cf_tOI_eqDE cf_tWE_eqDE cf_kHO_eqDE cf_kCE_eqDE cf_kDE_eqDE cf_kOI_eqDE cf_kWE_eqDE cfDE_eqDE `pscserDE')
*       (sOI: yOI = cf_wHO_eqOI cf_wCE_eqOI cf_wDE_eqOI cf_wOI_eqOI cf_wWE_eqOI cf_tHO_eqOI cf_tCE_eqOI cf_tDE_eqOI cf_tOI_eqOI cf_tWE_eqOI cf_kHO_eqOI cf_kCE_eqOI cf_kDE_eqOI cf_kOI_eqOI cf_kWE_eqOI cfOI_eqOI `pscserOI')
*       (sWE: yWE = cf_wHO_eqWE cf_wCE_eqWE cf_wDE_eqWE cf_wOI_eqWE cf_wWE_eqWE cf_tHO_eqWE cf_tCE_eqWE cf_tDE_eqWE cf_tOI_eqWE cf_tWE_eqWE cf_kHO_eqWE cf_kCE_eqWE cf_kDE_eqWE cf_kOI_eqWE cf_kWE_eqWE cfWE_eqWE `pscserWE')
*       , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate(`maxiter');
*       (sHO: yHO = cf_wHO_eqHO cf_wCE_eqHO cf_wDE_eqHO cf_wOI_eqHO cf_wWE_eqHO cf_tHO_eqHO cf_tCE_eqHO cf_tDE_eqHO cf_tOI_eqHO cf_tWE_eqHO cf_kHO_eqHO cf_kCE_eqHO cf_kDE_eqHO cf_kOI_eqHO cf_kWE_eqHO cfHO_eqHO `pscser'HO); /* left-out equation */
* };

est2vec translog`usemissg', e(N rss k_eq levels chi2_bp df_bp r2_1 chi2_1 p_1 r2_2 chi2_2 p_2 r2_3 chi2_3 p_3 r2_4 chi2_4 p_4) name(translog_`usemissg');

if `usemissg' == 0 {;
  order mneid sHO kHO tHO wHO cfHO sCE kCE tCE wCE cfCE sDE kDE tDE wDE cfDE sOI kOI tOI wOI cfOI sWE kWE tWE wWE cfWE;
  };
if `usemissg' >= 1 {;
  order mneid sHO kHO tHO wHO nofdiHO cfHO sCE kCE tCE wCE nofdiCE cfCE sDE kDE tDE wDE nofdiDE cfDE sOI kOI tOI wOI nofdiOI cfOI sWE kWE tWE wWE nofdiWE cfWE;
  };

* observation-specific predictions for extensive margins, sureg part;
*   operate on: pscCE pscDE pscOI pscWE;
*          and  pscCE_CE pscDE_CE pscOI_CE pscWE_CE pscDE_DE pscOI_DE pscWE_DE pscOI_OI pscWE_OI pscWE_WE;
*          and  pscCE_CE_CE pscDE_CE_CE pscOI_CE_CE pscWE_CE_CE pscDE_DE_CE pscOI_DE_CE pscWE_DE_CE pscOI_OI_CE pscWE_OI_CE pscWE_WE_CE pscDE_DE_DE pscOI_DE_DE pscWE_DE_DE pscOI_OI_DE pscWE_OI_DE pscWE_WE_DE pscOI_OI_OI pscWE_OI_OI pscWE_WE_OI pscWE_WE_WE;
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  * Evaluation of selection effects;
  foreach wreg in $regagg {;
    local w2dg = substr("`wreg'",1,2);
    local pspredacc "_b[s`r2dg':_cons]"; 
    local psrestacc "0";
    local psrestavgacc "0";
    if `usemissg'~=2  local pspredacc "`pspredacc' + _b[s`r2dg':psc`w2dg']*psc`w2dg'";
    if `usemissg'==2  local pspredacc "`pspredacc' + _b[s`r2dg':psc`w2dg'_eq`r2dg']*psc`w2dg'_eq`r2dg'";
    if `usemissg'~=2  local psmatacc "_b[s`r2dg':psc`w2dg']";
    if `usemissg'==2  local psmatacc "_b[s`r2dg':psc`w2dg'_eq`r2dg']";
    if `usemissg'~=2  tokenize `pscser'; 
    if `usemissg'==2  tokenize `pscser`r2dg''; 
    if `usemissg'~=2  local regrno : word count `pscser';
    if `usemissg'==2  local regrno : word count `pscser`r2dg'';
    forvalues i = 1/`regrno' {;
      local nami = subinstr("``i''","_eq`r2dg'","",.);
      capture egen double _MN`nami' = mean(``i'') if e(sample);
      };
    forvalues i = 1/`regrno' {;
      local `i' = subinstr("``i''","_eq`r2dg'","",.);
      if length(subinstr("``i''","`w2dg'","",.)) == length("``i''")-6 {; /* regional variable appears in cubic term: treat */
        if `usemissg'~=2  local pspredacc "`pspredacc' + _b[s`r2dg':``i'']*psc`w2dg'*psc`w2dg'*psc`w2dg'";
        if `usemissg'==2  local pspredacc "`pspredacc' + _b[s`r2dg':``i''_eq`r2dg']*psc`w2dg'_eq`r2dg'*psc`w2dg'*psc`w2dg'_eq`r2dg'";
        if `usemissg'~=2  local psmatacc "`psmatacc' + 3*_b[s`r2dg':``i'']*psc`w2dg'*psc`w2dg'";
        if `usemissg'==2  local psmatacc "`psmatacc' + 3*_b[s`r2dg':``i''_eq`r2dg']*psc`w2dg'_eq`r2dg'*psc`w2dg'_eq`r2dg'";
        };
      if length(subinstr("``i''","`w2dg'","",.)) == length("``i''")-4 & lower(subinstr("``i''","`w2dg'","",.))~=subinstr("``i''","`w2dg'","",.) {; /* regional variable appears in third-order interaction term: treat */
        local covar = subinstr(subinstr("``i''","`w2dg'","",.),"_","",.);
        if `usemissg'~=2  local pspredacc "`pspredacc' + _b[s`r2dg':``i'']*_MN`covar'*psc`w2dg'*psc`w2dg'";
        if `usemissg'==2  local pspredacc "`pspredacc' + _b[s`r2dg':``i''_eq`r2dg']*_MN`covar'*psc`w2dg'_eq`r2dg'*psc`w2dg'_eq`r2dg'";
        if `usemissg'~=2  local psmatacc "`psmatacc' + 2*_b[s`r2dg':``i'']*_MN`covar'*psc`w2dg'";
        if `usemissg'==2  local psmatacc "`psmatacc' + 2*_b[s`r2dg':``i''_eq`r2dg']*_MN`covar'*psc`w2dg'_eq`r2dg'";
        };
      if length(subinstr("``i''","`w2dg'","",.)) == length("``i''")-2 & lower(subinstr("``i''","`w2dg'","",.))~=subinstr("``i''","`w2dg'","",.) {; /* regional variable appears in second-order interaction term: treat */
        local covar1 = "psc" + substr(subinstr(subinstr("``i''","`w2dg'","",.),"_","",.),4,2);
        local covar2 = "psc" + substr(subinstr(subinstr("``i''","`w2dg'","",.),"_","",.),6,2);
        if "`covar2'"=="psc" {;
          if `usemissg'~=2  local pspredacc "`pspredacc' + _b[s`r2dg':``i'']*_MN`covar1'*psc`w2dg'";
          if `usemissg'==2  local pspredacc "`pspredacc' + _b[s`r2dg':``i''_eq`r2dg']*_MN`covar1'*psc`w2dg'_eq`r2dg'";
          if `usemissg'~=2  local psmatacc "`psmatacc' + _b[s`r2dg':``i'']*_MN`covar1'";
          if `usemissg'==2  local psmatacc "`psmatacc' + _b[s`r2dg':``i''_eq`r2dg']*_MN`covar1'";
          };
        if "`covar2'"~="psc" {;
          if `usemissg'~=2  local pspredacc "`pspredacc' + _b[s`r2dg':``i'']*_MN`covar1'*_MN`covar2'*psc`w2dg'";
          if `usemissg'==2  local pspredacc "`pspredacc' + _b[s`r2dg':``i''_eq`r2dg']*_MN`covar1'*_MN`covar2'*psc`w2dg'_eq`r2dg'";
          if `usemissg'~=2  local psmatacc "`psmatacc' + _b[s`r2dg':``i'']*_MN`covar1'*_MN`covar2'";
          if `usemissg'==2  local psmatacc "`psmatacc' + _b[s`r2dg':``i''_eq`r2dg']*_MN`covar1'*_MN`covar2'";
          };
        };
      if length(subinstr("``i''","`w2dg'","",.)) == length("``i''") {; /* regional variable does not appear in term: store for mean subtraction */
        if `usemissg'~=2  local psrestacc "`psrestacc' + _b[s`r2dg':``i'']*``i''";
        if `usemissg'==2  local psrestacc "`psrestacc' + _b[s`r2dg':``i''_eq`r2dg']*``i''_eq`r2dg'";
        if `usemissg'~=2  local psrestavgacc "`psrestavgacc' + _b[s`r2dg':``i'']*_MN``i''";
        if `usemissg'==2  local psrestavgacc "`psrestavgacc' + _b[s`r2dg':``i''_eq`r2dg']*_MN``i''";
        };
      };     
    * disp in yellow "`pspredacc'"; * disp in yellow "`psrestacc'"; * disp in yellow "`psrestavgacc'";
    qui gen double dy`r2dg'dps`w2dg' = `pspredacc' + `psrestavgacc' if e(sample);
    qui gen double _mdy`r2dg'psc`w2dg' = `psmatacc' if e(sample);
    qui summ _mdy`r2dg'psc`w2dg', meanonly;
    mat suredps[rownumb(suredps,"y_`reg'"),colnumb(suredps,"ps_`wreg'")] = `r(mean)';
    * CIs from SE of prediction (default);
    qui gen double dy`r2dg'dps`w2dg'_se = y`r2dg' - dy`r2dg'dps`w2dg' + `psrestavgacc' - `psrestacc' if e(sample);
    qui gen double dy`r2dg'dps`w2dg'_lcl = dy`r2dg'dps`w2dg' - invttail(e(df_m1),((100-${S_level})/200)) * dy`r2dg'dps`w2dg'_se if e(sample);
    qui gen double dy`r2dg'dps`w2dg'_ucl = dy`r2dg'dps`w2dg' + invttail(e(df_m1),((100-${S_level})/200)) * dy`r2dg'dps`w2dg'_se if e(sample);
    label var dy`r2dg'dps`w2dg' "Selection i`w2dg' effect on labor demand y`r2dg'";
    label var dy`r2dg'dps`w2dg'_lcl "${S_level}% CI i`w2dg' eff on empl y`r2dg'";
    label var dy`r2dg'dps`w2dg'_ucl "${S_level}% CI i`w2dg' eff on empl y`r2dg'";
    * sort psc`w2dg';
    * twoway connected dy`r2dg'dps`w2dg' dy`r2dg'dps`w2dg'_lcl dy`r2dg'dps`w2dg'_ucl psc`w2dg' if psc`w2dg'>=0 & psc`w2dg'<=1;
    * twoway connected dy`r2dg'dps`w2dg' psc`w2dg' if psc`w2dg'>=0 & psc`w2dg'<=1;
    drop _MN* dy`r2dg'dps`w2dg'_se;
    * drop _mdy`r2dg'psc`w2dg'; 
    }; /* close wreg loop */
  }; /* close reg loop */

sort mneid;
disp in gr "Matrix of selection effects on labor demand (usemissg: " in ye `usemissg' in gr ")";
mat list suredps;


/* initial concavity checks */
/*--------------------------*/

* matrix to check (i) that the fitted cost shares sLOC_predicted are nonnegative;
mat negxhatcnt`usemissg' = J(2,4,.);
matname negxhatcnt`usemissg' r(N_neg_xhare) r(N), rows(1..2) explicit;
local i = 0;
foreach sreg in sCE sDE sOI sWE {;
  local i = `i' + 1;
  matname negxhatcnt`usemissg' `sreg', columns(`i') explicit;
  predict _`sreg' if e(sample), equation(`sreg') xb;
  qui count if _`sreg'<0 & e(sample);
  mat negxhatcnt`usemissg'[1,`i']=`r(N)';
  qui count if e(sample);
  mat negxhatcnt`usemissg'[2,`i']=`r(N)';
  };
drop _s*;


/* sample statistics for elasticities of substitution */
/*----------------------------------------------------*/

order mneid nreg sec1_bem i* _I*;
summ2tex * if e(sample), c(mean sd N p50) name(summ_translog`usemissg') p(tex/v3npr/pt$par-af$aff-$waglvl-cf) replace detail;
preserve;
  foreach var in sHO sCE sDE sOI sWE wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE cfHO cfCE cfDE cfOI cfWE {;
    replace `var' = . if `var'==0;
    };
  summ2tex * if e(sample), c(mean sd N p50) name(summ_translog`usemissg'_missg) p(tex/v3npr/pt$par-af$aff-$waglvl-cf) replace detail;
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    summ2tex * if e(sample) & nofdi`r2dg'==0, c(mean sd N p50) name(summ_translog`usemissg'_missg`r2dg') p(tex/v3npr/pt$par-af$aff-$waglvl-cf) replace detail;
    };
restore;
corr2tex sHO sCE sDE sOI sWE if e(sample), name(corrT_translog`usemissg') p(tex/v3npr/pt$par-af$aff-$waglvl-cf) replace;


/* elasticities of substitution */
/*------------------------------*/

* Cross-wage coefficient matrix;
tempname VCE; /* resets prior `VCE' if defined */
tempname bcoef bse coefmat0 semat0 coefmat1 semat1 coefmat2 semat2 coefmat3 semat3 coefmat4 semat4; 
mat `bcoef' = e(b)';
mat `VCE' = e(V);  /* Heckman corrected if positive semi-definite under re-run */
mat `bse' = vecdiag(`VCE')';
* mat `bse' = vecdiag(`VCEkeep')'; /* Permit checking for symmetry in absence of Heckman correction */
foreach mattyp in coef se {;
  mat ``mattyp'mat0' = J(5,1,.);
  local cnt 0;
  foreach reg in $regagg {;
    local cnt = `cnt' + 1;
    local r2dg = substr("`reg'",1,2);
    if `usemissg'~=2  matorder `b`mattyp'', m(``mattyp'mat`cnt'') ifr(s`r2dg':cf_wHO s`r2dg':cf_wCE s`r2dg':cf_wDE s`r2dg':cf_wOI s`r2dg':cf_wWE);
    if `usemissg'==2  matorder `b`mattyp'', m(``mattyp'mat`cnt'') ifr(s`r2dg':cf_wHO_eq`r2dg' s`r2dg':cf_wCE_eq`r2dg' s`r2dg':cf_wDE_eq`r2dg' s`r2dg':cf_wOI_eq`r2dg' s`r2dg':cf_wWE_eq`r2dg');
    local col`cnt' : roweq ``mattyp'mat`cnt''; local col`cnt' = substr("`col`cnt''",1,3);
    };
  * mat list ``mattyp'mat1';
  * mat list ``mattyp'mat2';
  * mat list ``mattyp'mat3';
  * mat list ``mattyp'mat4';
  mat `mattyp'mat = ``mattyp'mat0' , ``mattyp'mat1' , ``mattyp'mat2' , ``mattyp'mat3' , ``mattyp'mat4';
  * mat list `mattyp'mat;
  mat ``mattyp'mat0' = `mattyp'mat[1,1..5] ';
  mat `mattyp'mat = ``mattyp'mat0' , ``mattyp'mat1' , ``mattyp'mat2' , ``mattyp'mat3' , ``mattyp'mat4';
  mat `mattyp'mat[1,1] = - (`mattyp'mat[2,1] + `mattyp'mat[3,1] + `mattyp'mat[4,1] + `mattyp'mat[5,1]);
  local collbl = subinstr("wHO `col1' `col2' `col3' `col4'","s","w",.);
  local rowlbl = "sHO `col1' `col2' `col3' `col4'";
  * disp "`collbl'";
  * disp "`rowlbl'";
  matname `mattyp'mat `collbl', columns(1..5) explicit;
  matname `mattyp'mat `rowlbl', rows(1..5) explicit;
};
* standard error for sHOwHO;
local sdHOHO = 0;
forvalues i = 2/5 {;
  forvalues j = 2/5 {;
    local sdHOHO = `sdHOHO' + semat[`i',`j'];
    };
  };
mat semat[1,1] = sqrt(`sdHOHO');
mat list coefmat; mat list semat;

* Observation-specific extensive margins;
tempname suredlnw;
mat `suredlnw' = suredps * pscdlnw;
foreach weff in HOM $regagg {;
  local w2dg = substr("`weff'",1,2);
  gen double xmrHOw`w2dg' = 0;
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    local regvar = "w_othr_`weff'";
    if "`weff'"=="HOM"  local regvar = "w_`weff'";
    local dpsc`r2dg'dw`w2dg' = `suredlnw'[rownumb(`suredlnw',"y_`reg'"),colnumb(`suredlnw',"w_`weff'")];
    * qui gen double xmr`r2dg'w`w2dg' = (_mdy`r2dg'pscCE*_mpscCEw`w2dg' + _mdy`r2dg'pscDE*_mpscDEw`w2dg' + _mdy`r2dg'pscOI*_mpscOIw`w2dg' + _mdy`r2dg'pscWE*_mpscWEw`w2dg') * i`r2dg'00 / cf`r2dg' ; /* if log wages used; observations */
    * qui gen double xmr`r2dg'w`w2dg' = (_mdy`r2dg'pscCE*_mpscCEw`w2dg' + _mdy`r2dg'pscDE*_mpscDEw`w2dg' + _mdy`r2dg'pscOI*_mpscOIw`w2dg' + _mdy`r2dg'pscWE*_mpscWEw`w2dg') * i`r2dg'00 * `regvar' / cf`r2dg' ; /* if plain wages used; observations */
    * qui gen double xmr`r2dg'w`w2dg' = `dpsc`r2dg'dw`w2dg'' * i`r2dg'00 / cf`r2dg' ; /* if log wages used; mean matrix */
    qui gen double xmr`r2dg'w`w2dg' = `dpsc`r2dg'dw`w2dg'' * i`r2dg'00 * `regvar' / cf`r2dg' ; /* if plain wages used; mean matrix */
    replace xmr`r2dg'w`w2dg'=. if abs(xmr`r2dg'w`w2dg')>1;  /* disregard implausible outliers */
    };
  };

* Save predictions by observation for twoway plots;
preserve;
  keep mneid dpsc??dw?? dpsc??dw??_lcl dpsc??dw??_ucl dy??dps?? dy??dps??_lcl dy??dps??_ucl xmr??w?? w_* psc??;
  sort mneid;
  if `usemissg'==1  save "$rootslct/Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-nonparam-relaxed", replace;
restore;

* Matrix of mean extensive margin correction terms;
capture mat drop xmrmat;
local rownames : rowfullnames coefmat;  /* Match regional pattern in coefmat at intensive margin */
local colnames : colfullnames coefmat;
local colnum : word count `colnames';
foreach reg in `rownames' {;
  local r2dg = substr("`reg'",-2,2);
  tempname xmat`r2dg';
  mat `xmat`r2dg'' = J(1,`colnum',.);
  matname `xmat`r2dg'' s`r2dg', rows(1) explicit;
  local colj = 0;
  foreach weff in `colnames' {;
    local colj = `colj' + 1;
    qui summ xmr`r2dg'`weff' if s`r2dg'~=0 & e(sample), meanonly;  /* only calculate mean over sample MNEs with presence */
    mat `xmat`r2dg''[1,`colj'] = r(mean);
    matname `xmat`r2dg'' `weff', columns(`colj') explicit;
    };
  capture mat xmrmat = xmrmat \ `xmat`r2dg'';
  if _rc {;
    mat xmrmat = `xmat`r2dg'';
    };
  };
foreach reg in `rownames' {;
  local r2dg = substr("`reg'",-2,2);
  disp; 
  disp "Coefficient on own-region propensity score in `r2dg': `pstrlg`r2dg''";
  disp "Extensive margin correction terms for `r2dg'";
  summ xmr`r2dg'w* if s`r2dg'~=0 & e(sample);
  };
mat list xmrmat;

* Statistics for matrices of shares (predicted shares recommended by Berndt 1991 and Hayashi 2000 but not used);
local eqs = subinstr("`rownames'","sHO","",.);
foreach reg in `eqs' {;
  local r2dg = substr("`reg'",-2,2);
  * qui predict double shat`r2dg', equation(s`r2dg') xb, if e(sample);
  gen double shat`r2dg' = s`r2dg';
  };
gen double shatHO = sHO;
preserve;
collapse (mean) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat);  /* Tmat to be transposed to a column vector below */
matname Tmat theta, rows(1) explicit;
restore, preserve;
collapse (sd) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat_sd);
matname Tmat_sd theta_sd, rows(1) explicit;
restore, preserve;
collapse (count) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat_N);
matname Tmat_N theta_N, rows(1) explicit;
restore, preserve;

* Zeta matrix (r2 in Anderson and Thursby 1986);
foreach sreg in HOM $regagg {;
  local sr2dg = substr("`sreg'",1,2);
  foreach wreg in HOM $regagg {;
    local wr2dg = substr("`wreg'",1,2);
    qui gen double r2s`sr2dg's`wr2dg' = Tmat_N[1,colnumb(Tmat_N,"s`sr2dg'")]^(-3) * ( ( s`sr2dg' - Tmat[1,colnumb(Tmat,"s`sr2dg'")] ) * ( s`sr2dg'*s`wr2dg' - Tmat[1,colnumb(Tmat,"s`sr2dg'")]*Tmat[1,colnumb(Tmat,"s`wr2dg'")] - corrT_translog`usemissg'_tbl[rownumb(corrT_translog`usemissg'_tbl,"s`sr2dg'"),colnumb(corrT_translog`usemissg'_tbl,"s`wr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`sr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`wr2dg'")] ) + Tmat_N[1,colnumb(Tmat_N,"s`sr2dg'")]*(Tmat_N[1,colnumb(Tmat_N,"s`sr2dg'")] - 1)*Tmat[1,colnumb(Tmat,"s`sr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`sr2dg'")]*( Tmat_sd[1,colnumb(Tmat_sd,"s`sr2dg'")] + corrT_translog`usemissg'_tbl[rownumb(corrT_translog`usemissg'_tbl,"s`sr2dg'"),colnumb(corrT_translog`usemissg'_tbl,"s`wr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`wr2dg'")] ) );
    };
  };
collapse (sum) r2sHOsHO r2sHOsCE r2sHOsDE r2sHOsOI r2sHOsWE r2sCEsHO r2sCEsCE r2sCEsDE r2sCEsOI r2sCEsWE r2sDEsHO r2sDEsCE r2sDEsDE r2sDEsOI r2sDEsWE r2sOIsHO r2sOIsCE r2sOIsDE r2sOIsOI r2sOIsWE r2sWEsHO r2sWEsCE r2sWEsDE r2sWEsOI r2sWEsWE if e(sample), fast;
tempname zetatmp;
mkmat r2sHOsHO r2sHOsCE r2sHOsDE r2sHOsOI r2sHOsWE r2sCEsHO r2sCEsCE r2sCEsDE r2sCEsOI r2sCEsWE r2sDEsHO r2sDEsCE r2sDEsDE r2sDEsOI r2sDEsWE r2sOIsHO r2sOIsCE r2sOIsDE r2sOIsOI r2sOIsWE r2sWEsHO r2sWEsCE r2sWEsDE r2sWEsOI r2sWEsWE, matrix(`zetatmp');
local shnames : colfullnames Tmat;
local shnames = subinstr("`shnames'","hat","",.);
mat zetamat = J(5,5,.);
matname zetamat `shnames', rows(1..5) explicit;
matname zetamat `shnames', columns(1..5) explicit;
foreach sr in `shnames' {;
  local sr2dg = subinstr("`sr'","s","",.);
  foreach wr in `shnames' {;
    local wr2dg = subinstr("`wr'","s","",.);
    mat zetamat[rownumb(zetamat,"`sr'"),colnumb(zetamat,"`wr'")] = `zetatmp'[1,colnumb(`zetatmp',"r2s`sr2dg's`wr2dg'")];
    };
  };
restore;

* Matrices of shares;
mat Tmat_all = Tmat \ Tmat_sd \ Tmat_N;
mat Tmat = Tmat'; /* Tmat transposed to a column vector */
mat Tsqmat = Tmat * Tmat';

* Calculate total cross-price elasticities (both margins);
mat TotElast = coefmat + xmrmat + Tsqmat;
forvalues r = 2/5 {; /* Fill lower-echelon entries */
local maxcol = `r'-1;
  forvalues m = 1/`maxcol' {;
    mat TotElast[`r',`m'] = TotElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues m = 2/5 {; /* Fill upper-echelon entries */
local maxrow = `m'-1;
  forvalues r = 1/`maxrow' {;
    mat TotElast[`r',`m'] = TotElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues r = 1/5 {;  /* Fill diagonal entries */
    mat TotElast[`r',`r'] = TotElast[`r',`r'] / Tmat[`r',1] - 1;
  };
matname TotElast `shnames', rows(1..5) explicit;
matname TotElast `shnames', columns(1..5) explicit;
mat list TotElast;
disp;

* Calculate cross-price elasticities matrix at extensive margin;
mat ExtElast = xmrmat + Tsqmat;
forvalues r = 2/5 {; /* Fill lower-echelon entries */
local maxcol = `r'-1;
  forvalues m = 1/`maxcol' {;
    mat ExtElast[`r',`m'] = ExtElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues m = 2/5 {; /* Fill upper-echelon entries */
local maxrow = `m'-1;
  forvalues r = 1/`maxrow' {;
    mat ExtElast[`r',`m'] = ExtElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues r = 1/5 {;  /* Fill diagonal entries and cancel HOM row */
    mat ExtElast[`r',`r'] = ExtElast[`r',`r'] / Tmat[`r',1] - 1;
    mat ExtElast[1,`r'] = 0;
  };
matname ExtElast `shnames', rows(1..5) explicit;
matname ExtElast `shnames', columns(1..5) explicit;
mat list ExtElast;
disp;

* Calculate cross-price elasticities matrix at intensive margin;
mat IntElast = coefmat + Tsqmat;
forvalues r = 2/5 {; /* Fill lower-echelon entries */
local maxcol = `r'-1;
  forvalues m = 1/`maxcol' {;
    mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues m = 2/5 {; /* Fill upper-echelon entries */
local maxrow = `m'-1;
  forvalues r = 1/`maxrow' {;
    mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues r = 1/5 {;  /* Fill diagonal entries */
    mat IntElast[`r',`r'] = IntElast[`r',`r'] / Tmat[`r',1] - 1;
  };
matname IntElast `shnames', rows(1..5) explicit;
matname IntElast `shnames', columns(1..5) explicit;
mat list IntElast;
disp;


/* additional concavity checks */
/*-----------------------------*/

* matrix to check (ii) that the cross price elasticities in TotElast sum to zero per row (not per column);
mat elastsum`usemissg' = J(2,5,0);
matname elastsum`usemissg' rowsum colsum, rows(1..2) explicit;
matname elastsum`usemissg' sHO sCE sDE sOI sWE, columns(1..5) explicit;
local i = 0;
foreach sreg in sHO sCE sDE sOI sWE {;
  local i = `i' + 1;
  forvalues j = 1/5 {;
    mat elastsum`usemissg'[1,`i'] = elastsum`usemissg'[1,`i'] + TotElast[`i',`j'];
    mat elastsum`usemissg'[2,`i'] = elastsum`usemissg'[2,`i'] + TotElast[`j',`i'];
    };
  };

* matrix to check (iii) that the AUmat matrices of Allen-Uzawa substitution elasticities are negative semi-definite at each observation;
* calculate MNE-level elasticities (in-sample predictions); 
* set elasticities to zero for regions with no FDI-presence;
local i = 0;
foreach reg1 in HO CE DE OI WE {;
  local i = `i' + 1;
  local j = 0;
  foreach reg2 in HO CE DE OI WE {;
    local j = `j' + 1;
    local coeff = coefmat[`i',`j'];
    if `i' ~= `j' {; 
      qui gen double sigma`reg1's`reg2' = (`coeff' + s`reg1' * s`reg2') / (s`reg1' * s`reg2') if e(sample);
      };
    if `i' == `j' {; 
      qui gen double sigma`reg1's`reg1' = (`coeff' + (s`reg1')^2 - s`reg1') / (s`reg1')^2 if e(sample);
      };      
    qui replace sigma`reg1's`reg2'=0 if sigma`reg1's`reg2'==.;
    label var sigma`reg1's`reg2' "AU elast. empl`reg1' empl`reg2'";
    };
  };
qui count;
local obsnum = `r(N)';
tempname AUmatobs eigenvec eigenval;
mat negeivalcnt`usemissg' = J(1,5,0) \ J(1,5,`obsnum');
matname negeivalcnt`usemissg' r(N_wklyneg_eigval) r(N), rows(1..2) explicit;
matname negeivalcnt`usemissg' wklyneg_1 wklyneg_2 wklyneg_3 wklyneg_4 wklyneg_5, columns(1..5) explicit;
forvalues obs = 1/`obsnum'{;
  mat `AUmatobs' = J(5,5,.);
  local i = 0;
  foreach reg1 in HO CE DE OI WE {;
    local i = `i' + 1;
    local j = 0;
    foreach reg2 in HO CE DE OI WE {;
      local j = `j' + 1;
      mat `AUmatobs'[`i',`j'] = sigma`reg1's`reg2'[`obs'];
      };
    };
  matrix symeigen `eigenvec' `eigenval' = `AUmatobs';
  matname `eigenval' `eigenval'ue, rows(1) explicit;
  mat drop `eigenvec';
  local cntwklyneg = 0;
  forvalues k = 1/5 {;
    if `eigenval'[1,`k'] <= 1.0e-06 {;  /* machine-size weakly negative */
      local cntwklyneg = `cntwklyneg' + 1;
      };
    };
  mat negeivalcnt`usemissg'[1,`cntwklyneg'] = negeivalcnt`usemissg'[1,`cntwklyneg']+1;
  };


/* matrix output */
/*---------------*/

foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  foreach type in b se e {;
    drop _all;
    matsave selreg`r2dg'_`type', p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/byreg) t(double) replace;
    };
  drop _all;
  matsave selreg`r2dg'_r, p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/byreg) t(double) replace;
  };

foreach type in b se e {;
    drop _all;
    matsave translog`usemissg'_`type', p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg') t(double) replace;
    };
matsave negxhatcnt`usemissg', p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace; 
matsave elastsum`usemissg', p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace; 
matsave negeivalcnt`usemissg', p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace; 

mat intelast`usemissg'_b = IntElast;
matsave intelast`usemissg'_b, p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;
mat extelast`usemissg'_b = ExtElast;
matsave extelast`usemissg'_b, p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;
mat totelast`usemissg'_b = TotElast;
matsave totelast`usemissg'_b, p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat vce`usemissg'_tbl = `VCE';
local cols = colsof(vce`usemissg'_tbl);
matsave vce`usemissg'_tbl, p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat tmat`usemissg'_tbl = Tmat_all;
matsave tmat`usemissg'_tbl, p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;
mat zetamat`usemissg'_tbl = zetamat;
matsave zetamat`usemissg'_tbl, p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat coefmat`usemissg'_tbl = coefmat;
matname coefmat`usemissg'_tbl wHO wCE wDE wOI wWE, columns(1..5) explicit;
matname coefmat`usemissg'_tbl sHO sCE sDE sOI sWE, rows(1..5) explicit;
matsave coefmat`usemissg'_tbl, p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat semat`usemissg'_tbl = semat;
matname semat`usemissg'_tbl wHO wCE wDE wOI wWE, columns(1..5) explicit;
matname semat`usemissg'_tbl sHO sCE sDE sOI sWE, rows(1..5) explicit;
matsave semat`usemissg'_tbl, p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat xmrmat`usemissg'_tbl = xmrmat;
matname xmrmat`usemissg'_tbl wHO wCE wDE wOI wWE, columns(1..5) explicit;
matname xmrmat`usemissg'_tbl sHO sCE sDE sOI sWE, rows(1..5) explicit;
matsave xmrmat`usemissg'_tbl, p(estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

* clean up;
drop _all;
mat drop coefmat semat xmrmat zetamat Tmat Tmat_sd Tmat_N Tmat_all Tsqmat TotElast ExtElast IntElast;
foreach mat in summ_translog`usemissg' summ_translog`usemissg'_missg corrT_translog`usemissg' vce`usemissg' coefmat`usemissg' semat`usemissg' tmat`usemissg' xmrmat`usemissg' zetamat`usemissg' {;
  mat drop `mat'_tbl;
  };
foreach type in b se e r {;
  capture mat drop translog`usemissg'_`type';
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    capture mat drop selreg`r2dg'_`type';
    capture mat drop selreg`r2dg'_`type';
    capture mat drop sure2stp`r2dg'_`type';
    };
  };
mat drop negxhatcnt`usemissg' elastsum`usemissg' negeivalcnt`usemissg';
mat drop totelast`usemissg'_b;
mat drop intelast`usemissg'_b;
mat drop extelast`usemissg'_b;
mat drop pscdlnw suredps;

}; /* end of `usemissg' loop */

log close;
cd "$root";
