*! version 1.3.6  14nov2006  by Marc Muendler muendler@ucsd.edu

* replace ${parnp_`xvars'} with ${paruse}
* replace `maxiter' with $maxiter

clear
set memory 400m
set matsize 400
set more off
capture log close

cd "$rootslct"

log using "logs/translog-selct-bstrap-pt$par-af$aff-$waglvl-nonparam-relaxed-allyrs.log", replace

*----------------------following code identical to translog-selct-2stp-bstrap-cf-nonparam-relaxed.do----------------------------
*-----substitute: /v3nprfs for /v3npr, now for 00, ${yrdiff}yrlg for 96 --------------------------------------------------------
*-----substitute: Xdata/mneid-forbstrap-$waglvl-pt$par-af$aff-cf-nonparam-relaxed-allyrs for Xdata/mneid-forbstrap-$waglvl-pt$par-af$aff-cf-nonparam-relaxed --

local reps = $reps
* ISUR with maximum number of iterations to avert non-convergence under bootstraps

local usexvar $usexvar  /* probit varlist to be used for selection correction in sureg */

#delimit ;

adopath + "$root/%stata/ado"; 


/* estimation routine */
/*--------------------*/
capture program drop surenpr;
program define surenpr;
  syntax [varlist], pscser(string) pscores(string) usemissg(integer);

  * sector dummies;
  qui summ sec1_bem;
  local minsec = `r(min)'+1;
  local maxsec = `r(max)';
  local dumlst = "_Isec1_bem_`minsec'";
  local secdum = "_b[_Isec1_bem_`minsec']*_Isec1_bem_`minsec'";
  local secavgdum = "_b[_Isec1_bem_`minsec']*_MN_Isec1_bem_`minsec'";
  local minsec = `minsec' + 1;
  forvalues j = `minsec'/`maxsec' {;
    local dumlst "`dumlst' _Isec1_bem_`j'";
    local secdum "`secdum' + _b[_Isec1_bem_`j']*_Isec1_bem_`j'";
    local secavgdum "`secavgdum' + _b[_Isec1_bem_`j']*_MN_Isec1_bem_`j'";
    };

  * matrices for marginal effects of wages on selection and of propensity scores on labor demand;
  mat pscdlnw = J(4,5,.);
  mat suredps = J(4,4,.);
  matrix rownames pscdlnw = $regagg;
  matrix rownames suredps = $regagg;
  matrix colnames pscdlnw = HOM $regagg;
  matrix colnames suredps = $regagg;
  local rownames : rowfullnames pscdlnw;
  local rownum : word count `rownames';
  tokenize `rownames';
  forvalues rowi = 1/`rownum' {;
    local rownew = "i_" + substr("``rowi''",-3,3);
    matname pscdlnw `rownew', rows(`rowi') explicit;
    local rownew = "y_" + substr("``rowi''",-3,3);
    matname suredps `rownew', rows(`rowi') explicit;
    };
  local colnames : colfullnames pscdlnw;
  local colnum : word count `colnames';
  tokenize `colnames';
  forvalues coli = 1/`colnum' {;
    local colnew = "w_" + substr("``coli''",-3,3);
    matname pscdlnw `colnew', columns(`coli') explicit;
    };
  local colnames : colfullnames suredps;
  local colnum : word count `colnames';
  tokenize `colnames';
  forvalues coli = 1/`colnum' {;
    local colnew = "ps_" + substr("``coli''",-3,3);
    matname suredps `colnew', columns(`coli') explicit;
    };

  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    tempname chk;

    * selection regressions without sector dummies (used for translog);
    local dumlst ""; /* no sector dummies */
    regress i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg ${paruse} ${addlvars};
    predict double psc`r2dg', xb;

    * observation-specific predictions for extensive margins, selection part;
      tokenize ${paruse} iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `dumlst';
      local regrno : word count ${paruse} iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `dumlst';
      forvalues i = 1/`regrno' {;
        local varname = subinstr("_MN``i''","othr_","",.);
        qui egen double `varname' = mean(``i'') if e(sample);
        };
      * operate on: w_HOM w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU w_HOM_2 w_othr_CEE_2 w_othr_DEV_2 w_othr_OIN_2 w_othr_WEU_2;
      *        and  w_HOM_CEE w_HOM_DEV w_HOM_OIN w_HOM_WEU w_HOM_inter w_HOM_mktacc w_CEE_DEV w_CEE_OIN w_CEE_WEU w_CEE_inter w_CEE_mktacc w_DEV_OIN w_DEV_WEU w_DEV_inter w_DEV_mktacc w_OIN_WEU w_OIN_inter w_OIN_mktacc;
      *        etc.;

      * Evaluation of wage effects;
      tokenize ${paruse};
      local regrno : word count ${paruse};
      foreach wreg in HOM $regagg {;
        local predacc "_b[_cons]";  /* predicted poynomial terms, varying only by `wreg' wage (all other vars are sample means) */
        * local restavgacc "`secavgdum' + _b[iCE${yrdiff}yrlg]*_MNiCE${yrdiff}yrlg + _b[iDE${yrdiff}yrlg]*_MNiDE${yrdiff}yrlg + _b[iOI${yrdiff}yrlg]*_MNiOI${yrdiff}yrlg + _b[iWE${yrdiff}yrlg]*_MNiWE${yrdiff}yrlg";  /* predicted remaining terms, not varying (sample means) */
        local restavgacc "_b[iCE${yrdiff}yrlg]*_MNiCE${yrdiff}yrlg + _b[iDE${yrdiff}yrlg]*_MNiDE${yrdiff}yrlg + _b[iOI${yrdiff}yrlg]*_MNiOI${yrdiff}yrlg + _b[iWE${yrdiff}yrlg]*_MNiWE${yrdiff}yrlg";  /* predicted remaining terms, not varying (sample means) */
        * local restacc "`secdum' + _b[iCE${yrdiff}yrlg]*iCE${yrdiff}yrlg + _b[iDE${yrdiff}yrlg]*iDE${yrdiff}yrlg + _b[iOI${yrdiff}yrlg]*iOI${yrdiff}yrlg + _b[iWE${yrdiff}yrlg]*iWE${yrdiff}yrlg";  /* predicted remaining terms, varying by all variables for standard error calculation */
        local restacc "_b[iCE${yrdiff}yrlg]*iCE${yrdiff}yrlg + _b[iDE${yrdiff}yrlg]*iDE${yrdiff}yrlg + _b[iOI${yrdiff}yrlg]*iOI${yrdiff}yrlg + _b[iWE${yrdiff}yrlg]*iWE${yrdiff}yrlg";  /* predicted remaining terms, varying by all variables for standard error calculation */
        local matacc "0";  /* marginal effect of `wreg' wage */
        * local chkacc "`predacc' + `restacc'";  /* for consistency checks (disabled) */
        local w2dg = substr("`wreg'",1,2);
        local regvar = "w_othr_`wreg'";
        if "`wreg'"=="HOM"  local regvar = "w_`wreg'";
        forvalues i = 1/`regrno' {;
          if length(subinstr("``i''","`wreg'","",.)) < length("``i''") {;  /* wage variable appears in token: treat */
            if lower(subinstr("``i''","`wreg'","",.)) == subinstr("``i''","`wreg'","",.) & substr(subinstr("``i''","`wreg'","",.),-1,1)=="_" {;  /* only `wreg' terms appear in token */
              local predacc "`predacc' + _b[``i'']*``i''";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-3  local matacc "`matacc' + _b[``i'']";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-6  local matacc "`matacc' + 2*_b[``i'']*`regvar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-9  local matacc "`matacc' + 3*_b[``i'']*w_`wreg'_`wreg'";
              * local chkacc "`chkacc' + _b[``i'']*``i''";
              };
            else {; /* mixed `wreg' and other terms appear in token */
              local covar = "_MN" + subinstr(subinstr(subinstr(subinstr("``i''","`wreg'","",.),"__","_",.),"__","_",.),"othr_","",.);
              if substr("`covar'",-1,1)=="_"  local covar = substr("`covar'",1,length("`covar'")-1);
              if lower(subinstr("`covar'","_MN","",.))==subinstr("`covar'","_MN","",.) & length("`covar'")<=12  local covar = subinstr("`covar'","w_","ln_",.);
              if lower(subinstr("`covar'","_MN","",.))==subinstr("`covar'","_MN","",.) & length("`covar'") >12  local covar = subinstr("`covar'","w_","",.);
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-3  local predacc "`predacc' + _b[``i'']*`regvar'*`covar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-6  local predacc "`predacc' + _b[``i'']*w_`wreg'_`wreg'*`covar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-3  local matacc "`matacc' + _b[``i'']*`covar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-6  local matacc "`matacc' + 2*_b[``i'']*`regvar'*`covar'";
              * local chkacc "`chkacc' + _b[``i'']*``i''";
              };
            };
          if length(subinstr("``i''","`wreg'","",.)) == length("``i''") {;  /* wage variable does not appear in token: store for mean subtraction */
            local exclvar = subinstr("``i''","othr_","",.);
            local restavgacc "`restavgacc' + _b[``i'']*_MN`exclvar'";
            local restacc "`restacc' + _b[``i'']*``i''";
            * local chkacc "`chkacc' + _b[``i'']*``i''";
            };
          };
        * disp in yellow "`predacc'"; * disp in yellow "`restacc'"; * disp in yellow "`restavgacc'"; * disp in yellow "`matacc'";
        qui gen double dpsc`r2dg'dw`w2dg' = `predacc' + `restavgacc' if e(sample);
        * qui gen double __chkacc = `chkacc' if e(sample);
        * summ __chkacc psc`r2dg';  /* check identity */
        * drop __chkacc;
        qui gen double _mpsc`r2dg'w`w2dg' = `matacc' if e(sample);
        qui summ _mpsc`r2dg'w`w2dg', meanonly;
        mat pscdlnw[rownumb(pscdlnw,"i_`reg'"),colnumb(pscdlnw,"w_`wreg'")] = `r(mean)';
        * drop _mpsc`r2dg'w`w2dg'; 
        }; /* close wreg loop */
      drop _MN*;
    };  /* close reg loop */

  * generate polynomial interaction terms for sureg regression;
  foreach var of local pscser {;
    if length("`var'")>5 {;
      local term = subinstr("`var'","_","*psc",.);
      qui gen double `var' = `term';
      label var `var' "(`term' for sureg)";
      if `usemissg'==2 {;
        foreach eqreg in $regagg {;
          local eqr2dg = substr("`eqreg'",1,2);
          qui gen double `var'_eq`eqr2dg' = `var';
          qui replace `var'_eq`eqr2dg' = 0 if y`eqr2dg'==0; /* nofdi`eqr2dg'==1 */;
          };
        };
      };
    };
  if `usemissg'==2 {;
    foreach var of local pscores {; /* var creation for `pscser' beyond `pscores' above */
      foreach eqreg in $regagg {;
        local eqr2dg = substr("`eqreg'",1,2);
        qui gen double `var'_eq`eqr2dg' = `var';
        qui replace `var'_eq`eqr2dg' = 0 if y`eqr2dg'==0; /* nofdi`eqr2dg'==1 */;
        };
      };
    tokenize `pscser';
    local num : word count `pscser';
    foreach eqreg in $regagg {;
      local eqr2dg = substr("`eqreg'",1,2);
      local pscser`eqr2dg' "";
      forvalues i = 1/`num' {;
        local pscser`eqr2dg' "`pscser`eqr2dg'' ``i''_eq`eqr2dg'";
        };
      };
    };

  * second step: seemingly unrelated regressions;
  if `usemissg' == 0 {;
  sureg (sCE: yCE = `varlist' cfCE `pscser')
        (sDE: yDE = `varlist' cfDE `pscser')
        (sOI: yOI = `varlist' cfOI `pscser')
        (sWE: yWE = `varlist' cfWE `pscser')
        , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate($maxiter);
  *     (sHO: yHO = `varlist' cfHO `pscser'); /* left-out equation */
  };
  if `usemissg' == 1 {;
  sureg (sCE: yCE = `varlist' nofdiDE nofdiOI nofdiWE cfCE `pscser')
        (sDE: yDE = `varlist' nofdiCE nofdiOI nofdiWE cfDE `pscser')
        (sOI: yOI = `varlist' nofdiCE nofdiDE nofdiWE cfOI `pscser')
        (sWE: yWE = `varlist' nofdiCE nofdiDE nofdiOI cfWE `pscser')
        , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate($maxiter);
  *     (sHO: yHO = `varlist' nofdiCE nofdiDE nofdiOI nofdiWE cfHO `pscser'); /* left-out equation */
  };
  if `usemissg' == 2 {;
  sureg (sCE: yCE = cf_wHO_eqCE cf_wCE_eqCE cf_wDE_eqCE cf_wOI_eqCE cf_wWE_eqCE cf_tHO_eqCE cf_tCE_eqCE cf_tDE_eqCE cf_tOI_eqCE cf_tWE_eqCE cf_kHO_eqCE cf_kCE_eqCE cf_kDE_eqCE cf_kOI_eqCE cf_kWE_eqCE nofdiDE_eqCE nofdiOI_eqCE nofdiWE_eqCE cfCE_eqCE `pscserCE')
        (sDE: yDE = cf_wHO_eqDE cf_wCE_eqDE cf_wDE_eqDE cf_wOI_eqDE cf_wWE_eqDE cf_tHO_eqDE cf_tCE_eqDE cf_tDE_eqDE cf_tOI_eqDE cf_tWE_eqDE cf_kHO_eqDE cf_kCE_eqDE cf_kDE_eqDE cf_kOI_eqDE cf_kWE_eqDE nofdiCE_eqDE nofdiOI_eqDE nofdiWE_eqDE cfDE_eqDE `pscserDE')
        (sOI: yOI = cf_wHO_eqOI cf_wCE_eqOI cf_wDE_eqOI cf_wOI_eqOI cf_wWE_eqOI cf_tHO_eqOI cf_tCE_eqOI cf_tDE_eqOI cf_tOI_eqOI cf_tWE_eqOI cf_kHO_eqOI cf_kCE_eqOI cf_kDE_eqOI cf_kOI_eqOI cf_kWE_eqOI nofdiCE_eqOI nofdiDE_eqOI nofdiWE_eqOI cfOI_eqOI `pscserOI')
        (sWE: yWE = cf_wHO_eqWE cf_wCE_eqWE cf_wDE_eqWE cf_wOI_eqWE cf_wWE_eqWE cf_tHO_eqWE cf_tCE_eqWE cf_tDE_eqWE cf_tOI_eqWE cf_tWE_eqWE cf_kHO_eqWE cf_kCE_eqWE cf_kDE_eqWE cf_kOI_eqWE cf_kWE_eqWE nofdiCE_eqWE nofdiDE_eqWE nofdiOI_eqWE cfWE_eqWE `pscserWE')
        , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate($maxiter);
  *     (sHO: yHO = cf_wHO_eqHO cf_wCE_eqHO cf_wDE_eqHO cf_wOI_eqHO cf_wWE_eqHO cf_tHO_eqHO cf_tCE_eqHO cf_tDE_eqHO cf_tOI_eqHO cf_tWE_eqHO cf_kHO_eqHO cf_kCE_eqHO cf_kDE_eqHO cf_kOI_eqHO cf_kWE_eqHO nofdiCE_eqHO nofdiDE_eqHO nofdiOI_eqHO nofdiWE_eqHO cfHO_eqHO `pscserHO'); /* left-out equation */
  };
  local collbl "wHO wCE wDE wOI wWE";
  local rowlbl "sCE sDE sOI sWE";
  mat coefmat = J(5,5,.);
  local i = 1;
  foreach lreg in `rowlbl' {;
    local i = `i' + 1;
    local j = 0;
    foreach wreg in `collbl'{;
      local j = `j' + 1;
      mat coefmat[`i',`j'] = _b[`lreg':cf_`wreg'];
      };
    mat coefmat[1,`i']= _b[`lreg':cf_wHO];
    };
  mat coefmat[1,1] = - (coefmat[2,1] + coefmat[3,1] + coefmat[4,1] + coefmat[5,1]);
  local rowlbl "sHO `rowlbl'";
  matname coefmat `collbl', columns(1..5) explicit;
  matname coefmat `rowlbl', rows(1..5) explicit;

  * observation-specific predictions for extensive margins, sureg part;
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    * Evaluation of selection effects;
    foreach wreg in $regagg {;
      local w2dg = substr("`wreg'",1,2);
      local pspredacc "_b[s`r2dg':_cons]"; 
      local psrestacc "0";
      local psrestavgacc "0";
      if `usemissg'~=2  local pspredacc "`pspredacc' + _b[s`r2dg':psc`w2dg']*psc`w2dg'";
      if `usemissg'==2  local pspredacc "`pspredacc' + _b[s`r2dg':psc`w2dg'_eq`r2dg']*psc`w2dg'_eq`r2dg'";
      if `usemissg'~=2  local psmatacc "_b[s`r2dg':psc`w2dg']";
      if `usemissg'==2  local psmatacc "_b[s`r2dg':psc`w2dg'_eq`r2dg']";
      if `usemissg'~=2  tokenize `pscser'; 
      if `usemissg'==2  tokenize `pscser`r2dg''; 
      if `usemissg'~=2  local regrno : word count `pscser';
      if `usemissg'==2  local regrno : word count `pscser`r2dg'';
      forvalues i = 1/`regrno' {;
        local nami = subinstr("``i''","_eq`r2dg'","",.);
        capture egen double _MN`nami' = mean(``i'') if e(sample);
        };
      forvalues i = 1/`regrno' {;
        local `i' = subinstr("``i''","_eq`r2dg'","",.);
        if length(subinstr("``i''","`w2dg'","",.)) == length("``i''")-6 {; /* regional variable appears in cubic term: treat */
          if `usemissg'~=2  local pspredacc "`pspredacc' + _b[s`r2dg':``i'']*psc`w2dg'*psc`w2dg'*psc`w2dg'";
          if `usemissg'==2  local pspredacc "`pspredacc' + _b[s`r2dg':``i''_eq`r2dg']*psc`w2dg'_eq`r2dg'*psc`w2dg'*psc`w2dg'_eq`r2dg'";
          if `usemissg'~=2  local psmatacc "`psmatacc' + 3*_b[s`r2dg':``i'']*psc`w2dg'*psc`w2dg'";
          if `usemissg'==2  local psmatacc "`psmatacc' + 3*_b[s`r2dg':``i''_eq`r2dg']*psc`w2dg'_eq`r2dg'*psc`w2dg'_eq`r2dg'";
          };
        if length(subinstr("``i''","`w2dg'","",.)) == length("``i''")-4 & lower(subinstr("``i''","`w2dg'","",.))~=subinstr("``i''","`w2dg'","",.) {; /* regional variable appears in third-order interaction term: treat */
          local covar = subinstr(subinstr("``i''","`w2dg'","",.),"_","",.);
          if `usemissg'~=2  local pspredacc "`pspredacc' + _b[s`r2dg':``i'']*_MN`covar'*psc`w2dg'*psc`w2dg'";
          if `usemissg'==2  local pspredacc "`pspredacc' + _b[s`r2dg':``i''_eq`r2dg']*_MN`covar'*psc`w2dg'_eq`r2dg'*psc`w2dg'_eq`r2dg'";
          if `usemissg'~=2  local psmatacc "`psmatacc' + 2*_b[s`r2dg':``i'']*_MN`covar'*psc`w2dg'";
          if `usemissg'==2  local psmatacc "`psmatacc' + 2*_b[s`r2dg':``i''_eq`r2dg']*_MN`covar'*psc`w2dg'_eq`r2dg'";
          };
        if length(subinstr("``i''","`w2dg'","",.)) == length("``i''")-2 & lower(subinstr("``i''","`w2dg'","",.))~=subinstr("``i''","`w2dg'","",.) {; /* regional variable appears in second-order interaction term: treat */
          local covar1 = "psc" + substr(subinstr(subinstr("``i''","`w2dg'","",.),"_","",.),4,2);
          local covar2 = "psc" + substr(subinstr(subinstr("``i''","`w2dg'","",.),"_","",.),6,2);
          if "`covar2'"=="psc" {;
            if `usemissg'~=2  local pspredacc "`pspredacc' + _b[s`r2dg':``i'']*_MN`covar1'*psc`w2dg'";
            if `usemissg'==2  local pspredacc "`pspredacc' + _b[s`r2dg':``i''_eq`r2dg']*_MN`covar1'*psc`w2dg'_eq`r2dg'";
            if `usemissg'~=2  local psmatacc "`psmatacc' + _b[s`r2dg':``i'']*_MN`covar1'";
            if `usemissg'==2  local psmatacc "`psmatacc' + _b[s`r2dg':``i''_eq`r2dg']*_MN`covar1'";
            };
          if "`covar2'"~="psc" {;
            if `usemissg'~=2  local pspredacc "`pspredacc' + _b[s`r2dg':``i'']*_MN`covar1'*_MN`covar2'*psc`w2dg'";
            if `usemissg'==2  local pspredacc "`pspredacc' + _b[s`r2dg':``i''_eq`r2dg']*_MN`covar1'*_MN`covar2'*psc`w2dg'_eq`r2dg'";
            if `usemissg'~=2  local psmatacc "`psmatacc' + _b[s`r2dg':``i'']*_MN`covar1'*_MN`covar2'";
            if `usemissg'==2  local psmatacc "`psmatacc' + _b[s`r2dg':``i''_eq`r2dg']*_MN`covar1'*_MN`covar2'";
            };
          };
        if length(subinstr("``i''","`w2dg'","",.)) == length("``i''") {; /* regional variable does not appear in term: store for mean subtraction */
          if `usemissg'~=2  local psrestacc "`psrestacc' + _b[s`r2dg':``i'']*``i''";
          if `usemissg'==2  local psrestacc "`psrestacc' + _b[s`r2dg':``i''_eq`r2dg']*``i''_eq`r2dg'";
          if `usemissg'~=2  local psrestavgacc "`psrestavgacc' + _b[s`r2dg':``i'']*_MN``i''";
          if `usemissg'==2  local psrestavgacc "`psrestavgacc' + _b[s`r2dg':``i''_eq`r2dg']*_MN``i''";
          };
        };     
    * disp in yellow "`pspredacc'"; * disp in yellow "`psrestacc'"; * disp in yellow "`psrestavgacc'";
    qui gen double dy`r2dg'dps`w2dg' = `pspredacc' + `psrestavgacc' if e(sample);
    qui gen double _mdy`r2dg'psc`w2dg' = `psmatacc' if e(sample);
    qui summ _mdy`r2dg'psc`w2dg', meanonly;
    mat suredps[rownumb(suredps,"y_`reg'"),colnumb(suredps,"ps_`wreg'")] = `r(mean)';
    drop _MN*;
    * drop _mdy`r2dg'psc`w2dg'; 
    }; /* close wreg loop */
  }; /* close reg loop */

  * observation-specific extensive margins;
  tempname suredlnw;
  mat `suredlnw' = suredps * pscdlnw;
  foreach weff in HOM $regagg {;
    local w2dg = substr("`weff'",1,2);
    gen double xmrHOw`w2dg' = 0;
    foreach reg in $regagg {;
      local r2dg = substr("`reg'",1,2);
      local regvar = "w_othr_`weff'";
      if "`weff'"=="HOM"  local regvar = "w_`weff'";
      local dpsc`r2dg'dw`w2dg' = `suredlnw'[rownumb(`suredlnw',"y_`reg'"),colnumb(`suredlnw',"w_`weff'")];
      * qui gen double xmr`r2dg'w`w2dg' = (_mdy`r2dg'pscCE*_mpscCEw`w2dg' + _mdy`r2dg'pscDE*_mpscDEw`w2dg' + _mdy`r2dg'pscOI*_mpscOIw`w2dg' + _mdy`r2dg'pscWE*_mpscWEw`w2dg') * i`r2dg'now / cf`r2dg' ; /* if log wages used; observations */
      * qui gen double xmr`r2dg'w`w2dg' = (_mdy`r2dg'pscCE*_mpscCEw`w2dg' + _mdy`r2dg'pscDE*_mpscDEw`w2dg' + _mdy`r2dg'pscOI*_mpscOIw`w2dg' + _mdy`r2dg'pscWE*_mpscWEw`w2dg') * i`r2dg'now * `regvar' / cf`r2dg' ; /* if plain wages used; observations */
      * qui gen double xmr`r2dg'w`w2dg' = `dpsc`r2dg'dw`w2dg'' * i`r2dg'now / cf`r2dg' ; /* if log wages used; mean matrix */
      qui gen double xmr`r2dg'w`w2dg' = `dpsc`r2dg'dw`w2dg'' * i`r2dg'now * `regvar' / cf`r2dg' ; /* if plain wages used; mean matrix */
      replace xmr`r2dg'w`w2dg'=. if abs(xmr`r2dg'w`w2dg')>1;  /* disregard implausible outliers */
      };
    };
 
  * Matrix of mean extensive margin correction terms;
  capture mat drop xmrmat;
  local rownames : rowfullnames coefmat;  /* Match regional pattern in coefmat at intensive margin */
  local colnames : colfullnames coefmat;
  local colnum : word count `colnames';
  foreach reg in `rownames' {;
    local r2dg = substr("`reg'",-2,2);
    tempname xmat`r2dg';
    mat `xmat`r2dg'' = J(1,`colnum',.);
    matname `xmat`r2dg'' s`r2dg', rows(1) explicit;
    local colj = 0;
    foreach weff in `colnames' {;
      local colj = `colj' + 1;
      qui summ xmr`r2dg'`weff' if s`r2dg'~=0 & e(sample), meanonly;  /* only calculate mean over sample MNEs with presence */
      mat `xmat`r2dg''[1,`colj'] = r(mean);
      matname `xmat`r2dg'' `weff', columns(`colj') explicit;
      };
    capture mat xmrmat = xmrmat \ `xmat`r2dg'';
    if _rc {;
      mat xmrmat = `xmat`r2dg'';
      };
    };

  calcelastnpr;
end;


/* elasticity posting */
/*--------------------*/
capture program drop calcelastnpr;
program define calcelastnpr, rclass;
  foreach reg in CE DE OI WE {;
    * qui predict double shat`reg', equation(s`reg') xb, if e(sample);
    qui gen double shat`reg' = s`reg';
    };
  qui gen double shatHO = sHO;
  collapse (mean) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
  mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat);  /* Tmat to be transposed to a column vector next */
  matname Tmat theta, rows(1) explicit;
  mat Tmat = Tmat';  /* Tmat transposed to a column vector */
  mat Tsqmat = Tmat * Tmat';

  * Calculate total cross-price elasticities (both margins);
  mat TotElast = coefmat + xmrmat + Tsqmat;
  forvalues r = 2/5 {; /* Fill lower-echelon entries */
  local maxcol = `r'-1;
    forvalues m = 1/`maxcol' {;
      mat TotElast[`r',`m'] = TotElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues m = 2/5 {; /* Fill upper-echelon entries */
  local maxrow = `m'-1;
    forvalues r = 1/`maxrow' {;
      mat TotElast[`r',`m'] = TotElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues r = 1/5 {; /* Fill diagonal entries */
      mat TotElast[`r',`r'] = TotElast[`r',`r'] / Tmat[`r',1] - 1;
    };

  * Calculate cross-price elasticities matrix at extensive margin;
  mat ExtElast = xmrmat + Tsqmat;
  forvalues r = 2/5 {; /* Fill lower-echelon entries */
  local maxcol = `r'-1;
    forvalues m = 1/`maxcol' {;
      mat ExtElast[`r',`m'] = ExtElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues m = 2/5 {; /* Fill upper-echelon entries */
  local maxrow = `m'-1;
    forvalues r = 1/`maxrow' {;
      mat ExtElast[`r',`m'] = ExtElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues r = 1/5 {;  /* Fill diagonal entries and cancel HOM row */
      mat ExtElast[`r',`r'] = ExtElast[`r',`r'] / Tmat[`r',1] - 1;
      mat ExtElast[1,`r'] = 0;
    };

  * Calculate cross-price elasticities matrix at intensive margin;
  mat IntElast = coefmat + Tsqmat;
  forvalues r = 2/5 {; /* Fill lower-echelon entries */
  local maxcol = `r'-1;
    forvalues m = 1/`maxcol' {;
      mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues m = 2/5 {; /* Fill upper-echelon entries */
  local maxrow = `m'-1;
    forvalues r = 1/`maxrow' {;
      mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues r = 1/5 {;  /* Fill diagonal entries */
      mat IntElast[`r',`r'] = IntElast[`r',`r'] / Tmat[`r',1] - 1;
    };

  * assemble elasticity estimate in one vector;
  foreach elsttyp in Int Ext Tot {;
    local cols = rowsof(`elsttyp'Elast) * colsof(`elsttyp'Elast) + colsof(`elsttyp'Elast);
    mat b`elsttyp'Elast = J(1,`cols',.);
    local i = 0;
    foreach regi in HO CE DE OI WE {;
      local i = `i' + 1;
      local j = 0;
      foreach regj in HO CE DE OI WE {;
        local j = `j' + 1;
        local col = (`i'-1)*colsof(`elsttyp'Elast) + `j';
        mat b`elsttyp'Elast[1,`col'] = `elsttyp'Elast[`i',`j'];
        matname b`elsttyp'Elast `elsttyp'_l`regi'_w`regj', columns(`col') explicit;
        };
      local thetacol = rowsof(`elsttyp'Elast) * colsof(`elsttyp'Elast) + `i';
      qui summ shat`regi', meanonly;
      mat b`elsttyp'Elast[1,`thetacol'] = `r(mean)';
      matname b`elsttyp'Elast `elsttyp'_s`regi'mean, columns(`thetacol') explicit;
      };
    };
  mat bElast = bTotElast , bExtElast , bIntElast;

  * drop entries with missing information (first entry missing will result in error);
  local j 1;
  local cols = colsof(bElast);
  while `j' <= `cols'-1 {;
    local j = `j' + 1;
    local cols = colsof(bElast);
    if bElast[1,`j']==.  mat bElast = bElast[1,1..`j'-1] , bElast[1,`j'+1..`cols'];
    };

  * tempvar touse; /* not used b/c two steps operate on different samples */
  * gen byte `touse' = e(sample);

  tempname pseudocov;
  local cols = colsof(bElast);
  local colnams : colfullnames bElast;
  matrix `pseudocov' = -999*I(`cols');
  matrix colnames `pseudocov' = `colnams';
  matrix rownames `pseudocov' = `colnams';

  * ereturn post bElast `pseudocov', esample(`touse');
  ereturn post bElast `pseudocov';
  
end;


/* define X-equation restrictions */
/*--------------------------------*/

* constraint define  1 [sCE]cf_wHO = [sHO]cf_wCE;
  constraint define  2 [sCE]cf_wDE = [sDE]cf_wCE;
  constraint define  3 [sCE]cf_wOI = [sOI]cf_wCE;
  constraint define  4 [sCE]cf_wWE = [sWE]cf_wCE;
* constraint define  5 [sDE]cf_wHO = [sHO]cf_wDE;
  constraint define  6 [sDE]cf_wOI = [sOI]cf_wDE;
  constraint define  7 [sDE]cf_wWE = [sWE]cf_wDE;
* constraint define  8 [sOI]cf_wHO = [sHO]cf_wOI;
  constraint define  9 [sOI]cf_wWE = [sWE]cf_wOI;
* constraint define 10 [sWE]cf_wHO = [sHO]cf_wWE;
* constraint define 11 [sHO]cf_wHO + [sHO]cf_wCE + [sHO]cf_wDE + [sHO]cf_wOI + [sHO]cf_wWE = 0;
  constraint define 12 [sCE]cf_wHO + [sCE]cf_wCE + [sCE]cf_wDE + [sCE]cf_wOI + [sCE]cf_wWE = 0;
  constraint define 13 [sDE]cf_wHO + [sDE]cf_wCE + [sDE]cf_wDE + [sDE]cf_wOI + [sDE]cf_wWE = 0;
  constraint define 14 [sOI]cf_wHO + [sOI]cf_wCE + [sOI]cf_wDE + [sOI]cf_wOI + [sOI]cf_wWE = 0;
  constraint define 15 [sWE]cf_wHO + [sWE]cf_wCE + [sWE]cf_wDE + [sWE]cf_wOI + [sWE]cf_wWE = 0;

/* With 5 regions, there are (5*5-5)/2=10 symmetry restrictions in principle. 
   However, one equation drops due to further cross-equation constraints, 
   only 6 of the symmetry restrictions are needed.
   Similarly, only 4 of the 5 restrictions on wage parameter sums are needed. */

/* variable sets for selection estimation */
/*----------------------------------------*/

do $dp/!varsets-np.do;


/* nonparametric base variables for sureg estimation */
/*---------------------------------------------------*/

local pscores "pscCE pscDE pscOI pscWE"; /* first-order terms */
local regord = trim(subinstr("`pscores'","psc","",.));
local pscser2 ""; /* second-order terms */
local cnt 0;
foreach reg in `regord' {;
  local cnt = `cnt' + 1;
  local r2dg = substr("`reg'",1,2);
  tokenize `pscores';
  local pscno : word count `pscores';
  forvalues i = `cnt'/`pscno' {;
    local addtrm "``i''_`r2dg'";
    local pscser2 "`pscser2' `addtrm'";
    };
  };
local pscser3 ""; /* third-order terms */
local cnt 1;
local strt 0;
foreach reg in `regord' {;
  local strt = `strt' + `cnt';
  local r2dg = substr("`reg'",1,2);
  tokenize `pscser2';
  local pscno : word count `pscser2';
  local cnt 0;
  forvalues i = `strt'/`pscno' {;
    * if length(subinstr("``i''",substr("``i''",-2,2),"",.))==4 {; /* operate only on square terms, not in general on interaction terms */
    if substr("``i''",-2,2)=="`r2dg'"  local cnt = `cnt' + 1;
    local addtrm "``i''_`r2dg'";
    local pscser3 "`pscser3' `addtrm'";
    * };
    };
  };
local pscser "`pscores'`pscser2'`pscser3'";


/* data and main loop */
/*--------------------*/

foreach usemissg in $howmany {; /* begin `usemissg' loop */

capture mkdir "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'";

use "$rootslct/Xdata/mneid-forbstrap-$waglvl-pt$par-af$aff-cf-nonparam-relaxed-allyrs", clear;
drop dpsc??dw?? dpsc??dw??_lcl dpsc??dw??_ucl psc??;


/* Bootstrap SUR under restrictions */
/*----------------------------------*/

* surenpr cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE, pscser(`pscser') pscores(`pscores') usemissg(`usemissg');
* mat bElast = e(b);
* mat list bElast;

if `usemissg'~=2  keep mneid sec1_bem iHOnow iCEnow iDEnow iOInow iWEnow yHO yCE yDE yOI yWE sHO sCE sDE sOI sWE iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg ${paruse} cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiWE nofdiOI nofdiCE nofdiDE cfHO cfWE cfOI cfCE cfDE;
if `usemissg'==2  keep mneid sec1_bem iHOnow iCEnow iDEnow iOInow iWEnow yHO yCE yDE yOI yWE sHO sCE sDE sOI sWE iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg ${paruse} cf_wHO* cf_wCE* cf_wDE* cf_wOI* cf_wWE* cf_tHO* cf_tCE* cf_tDE* cf_tOI* cf_tWE* cf_kHO* cf_kCE* cf_kDE* cf_kOI* cf_kWE* nofdiWE* nofdiOI* nofdiCE* nofdiDE* cfHO* cfWE* cfOI* cfCE* cfDE*;
* surenpr cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE, pscser(`pscser') pscores(`pscores') usemissg(`usemissg');

bootstrap "surenpr cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE, pscser(`pscser') pscores(`pscores') usemissg(`usemissg')" _b, 
        reps(`reps') double saving(estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap) every(50) dots replace;

mat drop coefmat xmrmat TotElast ExtElast IntElast bTotElast bExtElast bIntElast Tmat Tsqmat pscdlnw suredps;

}; /* end of `usemissg' loop */

capture program drop surenpr;
capture program drop calcelastnpr;

*----------------------above code identical to translog-selct-2stp-bstrap-cf-nonparam-relaxed.do--------------------------------;

log close;
cd "$root";
