*! version 1.0.1  01mar2005  by Robert Jaeckle jaeckle@ifo.de
*! version 1.1.9  09apr2006  by Marc Muendler  muendler@ucsd.edu
*! version 1.2.2  14nov2006  by Marc Muendler  muendler@ucsd.edu

* All economic figures in plain EUR from 2. GERMAN DATA on (but not in 1. SUMMARIZE)
* #bemfiles.do transforms monetary variables to plain EUR
* Employment in number of persons

* NOTE: To transform Swedish do files to German do files
*       0. Retain the file name
*       1. In the do file code, replace "sweden" with "pt$par-af$aff" (or "pt$par-af`aff'" in rare circumstances in %45/)
*       2. In the do file code, replace "outwfdi-iui-" with "outwfdi-ustan-"
*       3. In prep-parent-hostcntry-data-selct.do, replace "affils-parnts-sweden-94&98-plaineur" with "affils-fdi-ustan-96&00-plaineur"
* Never change country references in # files

set seed 49601962
program drop _all
mat drop _all
macro drop _all
set trace off

* global root "c:/becker_muendler"
* global root "R:/Zentrale/6/Daten/6_Extern/!Fdi-Projekte/Muendler"
global root "//acsnfs4/unix-home/econgrad/marcm/fdilabor"
* global root "c:/data/fdilabor"

* global rootslct "C:/Home/Muendler/!fdiselct"
* global rootslct "R:/Zentrale/6/Daten/6_Extern/!Fdi-Projekte/Muendler/!fdiselct"
global rootslct "//acsnfs4/unix-home/econgrad/marcm/fdiselct"
* global rootslct "g:/data/fdiselct"

* global rootdo "c:/becker_muendler"
* global rootdo "R:/Zentrale/6/Daten/6_Extern/!Fdi-Projekte/Muendler"
global rootdo "//acsnfs4/unix-home/econgrad/marcm/fdiselct"
* global rootdo "c:/data/fdiselct"

do "$root/%stata/%Settings.do"
do "$root/%stata/ado/%Read-tabl2tex.do" /* Reads the programs summ2tex, tabl2tex and corr2tex for later use (to become an ado file later) */
do "$root/%stata/ado/%Read-est2tex.do"  /* Reads the packages est2tex and matsave (to avoid overlaps with old versions on outside computers) */
adopath + "$root/%stata/ado"
cd "$root"

global regdef "APC CEE EMU ODV OIN OWE RCA"
global reghomdef "APC CEE EMU HOM ODV OIN OWE RCA"
global regagg "CEE DEV OIN WEU"
global reghomagg "CEE DEV HOM OIN WEU"

capture mkdir "$rootslct/estmat"
capture mkdir "$rootslct/logs"
capture mkdir "$rootslct/tex"
capture mkdir "$rootslct/Xdata"

global par = "manf" /* Keep manufacturing parents only (alternatives: "all", "nonmf") */
global aff = "manf" /* Keep manufacturing affiliates only (alternatives: "all", "nonmf") */
global share .5     /* Keep majority-owned affiliates only (ownership share strictly exceeds value .5) */

global reps 200   /* 200 bootstrap repetitions */
global maxiter 25 /* 25 maximum likelihood iterations */
global usexvar 3  /* selection regression specification */
global howmany 1  /* "0 1 2" treatments for missing locations; reset before programs below */


* 0. AUXILIARY DATA PREPARATION
*------------------------------

global dp "$root/%stata/%00prepare-external"
*  do $dp/read-oww-data.do
*  do $dp/ubs-data-1994-2003.do
*  do $dp/unido-wages-1995-2001.do
*  do $dp/destatis-data-1996-2002.do
*  do $dp/market-potential.do
*  do $dp/swewages.do
*  do $dp/swecostcapital.do


* 1. GERMAN DATA PREPARATION FOR REGRESSIONS (%40)
*-------------------------------------------------
* all economic figures in plain EUR from here on

global addlmne "indwest_par_1996"
global addlsec "union_1996 imp_CEE_2000 exp_CEE_2000 impinp_CEE_2000 imp_DEV_2000 exp_DEV_2000 impinp_DEV_2000 imp_OIN_2000 exp_OIN_2000 impinp_OIN_2000 imp_WEU_2000 exp_WEU_2000 impinp_WEU_2000"

global dpref "$rootdo/%stata/%40selct-ger-prep"

    do $dpref/#bemfiles.do
    /* Makes DIREK-USTAN data comparable to IUI data */
    /* INPUT   "$root/Xmatch/affils-fdiall-ustan-96-01-eur-03mar2006.dta"
               "$root/Xustan/ustan-compl-03mar2006.dta" */
    /* DO      "$dp/#variable-creation-direk.do"
               "$dp/#variable-creation-ustan.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/affils-fdi-ustan-96&00-plaineur.dta"
               "$rootslct/Xdata/affils-fdiall-ustan-00-plaineur.dta"
               "$rootslct/Xdata/ustan-compl-plaineur.dta"
       Log:    "$rootslct/logs/bemfiles-ger.log" */

    do $dpref/#reg-pop-pattern-ger.do
    /* Prepares patterns of regional presence for estimation (and makes summary statistics) */
    /* INPUT   "$root/Xdata/affils-outwfdi96-01-eur-03mar2006.dta"
               "$root/conc/fdi-iso-country.dta"
               "$root/conc/cntry2bemgrp.dta"
               "$root/conc/sector-conc-nace.dta"
               "$root/conc/secfix.csv"
               "$root/conc/sector-conc-bem.dta"
               "$root/conc/sector-conc-aggbem.dta" */
    /* DO      "$dp/#sector-definitions.do"
               "$dp/#sector-country-resetting.do"
               "$root/conc/secbem.do"
               "$root/conc/sec7ltr.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff.dta"
       TeX:    "$rootslct/tex/pop/pt$par-af$aff/summ_del_naff.tex"   
               "$rootslct/tex/pop/pt$par-af$aff/summ_del_naff96.tex"
               "$rootslct/tex/pop/pt$par-af$aff/summ_del_naff00.tex"
               "$rootslct/tex/pop/pt$par-af$aff/delnaff.tex"
               "$rootslct/tex/pop/pt$par-af$aff/delncty.tex"
               "$rootslct/tex/pop/pt$par-af$aff/pattern96.tex"
               "$rootslct/tex/pop/pt$par-af$aff/pattern00.tex"
               "$rootslct/tex/pop/pt$par-af$aff/countries_compl.tex"
               "$rootslct/tex/pop/pt$par-af$aff/countries.tex"
       Log:    "logs/reg-pop-pattern-ger-pt$par-af$aff.log" */

    do $dpref/prep-parent-hostcntry-data-selct.do
    /* Prepares parent-host country level data */
    /* INPUT   "$rootslct/Xdata/affils-fdi-ustan-96&00-plaineur.dta"
               "$root/conc/sector-conc-nace.dta"
               "$root/conc/cntry2bemgrp.dta"
               "$root/conc/secfix.csv"
               "$root/conc/sector-conc-bem.dta"
               "$root/conc/sector-conc-aggbem.dta" */
    /* DO      "$dp/#sector-definitions.do"
               "$dp/#sector-country-resetting.do"
               "$root/conc/secbem.do"
               "$root/conc/sec7ltr.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff.dta"
       Log:    "$rootslct/logs/prep-parent-hostcntry-data-selct-pt$par-af$aff.log" */

global waglvl = "frmowwwage"
    do $dpref/prep-mvprobit-med-wagediff.do
global waglvl = "frmubswage"
* do $dpref/prep-mvprobit-med-wagediff.do
global waglvl = "frmunowage"
    do $dpref/prep-mvprobit-med-wagediff.do
    /* Prepares parent-region level data for (mv)probit estimates (years 1996 & 2000)*/
    /* INPUT   "$rootslct/Xdata/ustan-compl-plaineur.dta"
               "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff.dta"
               "$root/Xmatch/affils-fdiall-ustan-96-01-eur-03mar2006.dta"
               "$root/countries/extdata-deflated.dta"
               "$root/wages/destatis-gearn-defl.dta"
               "$root/wages/owwdata-country-`year'.dta" (where `year' in 1996 1999)
               "$root/wages/ubs-data-1996-2001-defl-interpolated.dta"
               "$root/wages/unido-wages-defl-1996-2001.dta"
               "$root/wages/swewages.dta"
               "$root/wages/union_sec_bem.dta"
               "$root/trade/ger-impinp-exp-secbem-ctrygrp-2000.dta"
               "$root/conc/cntry2bemgrp.dta" 
               "$root/conc/fdi-iso-country.dta"
               "$root/conc/nace2bem.dta"
               "$root/conc/sector-conc-nace.dta"
               "$root/conc/sector-conc-bem.dta" */
    /* DO      "$dpref/#wage-diff-$waglvl.do"
               "$dpref/#translog-owwwages.do"
               "$dpref/#translog-ubswages.do"
               "$dpref/#translog-unowages.do"
               "$dpref/#parinfo-probit.do"
               "$dpref/#addlvars.do"
               "$root/conc/secbem.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mvprobit-outwfdi-ustan-2000-$waglvl-pt$par-af$aff.dta"
               "$rootslct/tex/desc/wagediffs/diffsger`yr'-$waglvl.dta" (where `yr' in 96 and 00)
       Log:    "$rootslct/logs/mvprobit-prepare-selct-$waglvl-pt$par-af$aff.log" */

global waglvl = "frmowwwage"
    do $dpref/prep-translog-fdidata.do
global waglvl = "frmubswage"
* do $dpref/prep-translog-fdidata.do
global waglvl = "frmunowage"
    do $dpref/prep-translog-fdidata.do
    /* Prepares parent-host country level data for Translog regressions */
    /* INPUT   "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff.dta"
               "$root/wages/destatis-gearn-defl.dta"
               "$root/wages/owwdata-country-`year'.dta" (where `yr' in 1996 1999)
               "$root/wages/ubs-data-1996-2001-defl-interpolated.dta"
               "$root/wages/unido-wages-defl-1996-2001.dta"
               "$root/wages/swewages.dta"
               "$root/conc/fdi-iso-country.dta"
               "$root/conc/cntry2bemgrp.dta" 
               "$root/conc/sector-conc-nace.dta"
               "$root/conc/sector-conc-bem.dta" */
    /* DO      "$dp/#translog-owwwages.do"
               "$dp/#translog-ubswages.do"
               "$dp/#translog-unowages.do"
               "$dp/#translog-yearselect-wages.do"
               "$dp/#translog-avgswe-wages.do" 
               "$root/conc/secbem.do" */
    /* OUTPUT
       Data:   "$rootslct/tex/desc/pt$par-af$aff/employment-aggregates-`year'.dta" (where `year' in 1996 2000)
               "$rootslct/Xdata/mneid-outwfdi-ustan-`year'-translog-$waglvl-pt$par-af$aff.dta" (where `year' in 1996 2000)
       Log:    "$rootslct/logs/prep-translog-fdi-data-$waglvl-pt$par-af$aff.log" */

global method "impfillin"
    do $dpref/prep-vars-others.do
    /* Prepares location-specific variables as competitors' exposure */
    /* INPUT   "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff.dta"
               "$root/trade/mkt-access-$method-`year'.dta" (where `year' in 1996 2000)
               "$root/countries/barro-lee-99-pwt-iso.dta"
               "$root/countries/extdata-deflated.dta" 
               "$root/countries/dist-deu.dta"
               "$root/conc/fdi-iso-country.dta"
               "$root/conc/cntry2bemgrp.dta"
               "$root/conc/direk-cntrylist.csv" */
    /* DO      "$dp/#wdi-external.do"
               "$root/conc/land.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-outwfdi-ustan-`year'-locvars-pt$par-af$aff.dta" (where `year' in 1996, 2000)
               "$rootslct/Xdata/mneid-outwfdi-ustan-`year'-wwlocvars-pt$par-af$aff.dta" (where `year' in 1996, 2000)
       Log:    "$rootslct/logs/prep-vars-others-pt$par-af$aff.log" */

global waglvl = "frmowwwage"
    do $dpref/prep-costs-others.do
global waglvl = "frmubswage"
* do $dpref/prep-costs-others.do
global waglvl = "frmunowage"
    do $dpref/prep-costs-others.do
    /* Prepares competitors' wage and non-wage variables */
    /* INPUT   "$rootslct/Xdata/mneid-outwfdi-ustan-`year'-translog-$waglvl-pt$par-af$aff.dta" (where `year' in 1996, 2000) */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-outwfdi-ustan-`year'-costothr-$waglvl-pt$par-af$aff.dta" (where `year' in 1996, 2000)
       Log:    "$rootslct/logs/prep-costs-others-$waglvl-pt$par-af$aff.log" */


* 2. REGRESSIONS ON GERMAN DATA FOR SELECTION PAPER (%42)
*--------------------------------------------------------

global addlmne "indwest_par_1996"
global addlsec "union_1996 imp_CEE_2000 exp_CEE_2000 impinp_CEE_2000 imp_DEV_2000 exp_DEV_2000 impinp_DEV_2000 imp_OIN_2000 exp_OIN_2000 impinp_OIN_2000 imp_WEU_2000 exp_WEU_2000 impinp_WEU_2000"

global dp "$rootdo/%stata/%42selct-ger-reg"

global waglvl = "frmowwwage"
* do $dp/reg-extmarg.do
global waglvl = "frmubswage"
* do $dp/reg-extmarg.do
global waglvl = "frmunowage"
* do $dp/reg-extmarg.do
    /* Runs simple regressions to assess regional presence */
    /* INPUT   "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff.dta"
               "$rootslct/Xdata/mvprobit-outwfdi-ustan-2000-$waglvl-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-wwlocvars-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-costothr-$waglvl-pt$par-af$aff.dta" 
               "$rootslct/Xdata/mneid-outwfdi-ustan-2000-translog-$waglvl-pt$par-af$aff.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3/pt$par-af$aff-$waglvl/extmarg/olsnaff`r2dg'_`type'.dta" (where `type' in b se e)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl/extmarg/olsempl`r2dg'_`type'.dta" (where `type' in b se e)
       Log:    "$rootslct/logs/reg-extmarg-$waglvl-pt$par-af$aff.log" */

global waglvl = "frmowwwage"
* do $dp/probit-selct.do
global waglvl = "frmubswage"
* do $dp/probit-selct.do
global waglvl = "frmunowage"
* do $dp/probit-selct.do
    /* Estimates probit location choices */
    /* INPUT   "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-2000-translog-$waglvl-pt$par-af$aff.dta" 
               "$rootslct/Xdata/mvprobit-outwfdi-ustan-2000-$waglvl-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-costothr-$waglvl-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-wwlocvars-pt$par-af$aff.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/probit/dprobit`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/probit/probit`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e r)
       Log:    "$rootslct/logs/probit-selct-$waglvl-pt$par-af$aff.log" */


global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-cf.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf.do
global waglvl = "frmunowage"
    do $dp/translog-selct-2stp-cf.do
    /* Estimates translog cost shares and elasticities under selection in a two-step approach */
    /* INPUT   "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-2000-translog-$waglvl-pt$par-af$aff.dta" 
               "$rootslct/Xdata/mvprobit-outwfdi-ustan-2000-$waglvl-pt$par-af$aff.dta" 
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-costothr-$waglvl-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-wwlocvars-pt$par-af$aff.dta" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf.dta" 
       Tables: "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/byreg/dprobit`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e r)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/byreg/probit`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/byreg/sure2stp`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1 and `type' in b se e)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negsharcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'_tbl.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/vce`usemissg'_tbl.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta" 
       TeX:    "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'.tex"
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_missg.tex"
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/corrT_translog`usemissg'.tex"
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf.log" */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-bstrap-cf.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-bstrap-cf.do
global waglvl = "frmunowage"
    do $dp/translog-selct-2stp-bstrap-cf.do
    /* Bootstraps the estimates of translog cost shares and elasticities under selection from two-step approach */
    /* INPUT   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1)
       Log:    "$rootslct/logs/translog-selct-bstrap-pt$par-af$aff-$waglvl.log" */

global waglvl = "frmowwwage"
* do $dp/tab-estmat-selct-cf.do
global waglvl = "frmubswage"
* do $dp/tab-estmat-selct-cf.do
global waglvl = "frmunowage"
* do $dp/tab-estmat-selct-cf.do
    /* Saves TeX tables of selection and elasticity estimates with their bootstrapped standard errors, graphs kernels of eigenvalues */
    /* INPUT   "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/byreg/probit`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/byreg/dprobit`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1, and `type' in b se e r)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negxhatcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/sunkcost.tex"
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/probit_txt.tex"
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/probit_apx1.tex"
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/probit_apx2.tex"
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/probit_apx3.tex"
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/dprobit_txt.tex"
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/dprobit_apx1.tex"
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/dprobit_apx2.tex"
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/dprobit_apx3.tex"
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/intelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/extelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/totelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/intmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/extmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/totmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/eigval`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/possharcnt`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/elastsum`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/negeivalcnt`usemissg'.tex" (where `usemissg' in 0 1) 
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/compelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3/pt$par-af$aff-$waglvl-cf/compmori`usemissg'.tex" (where `usemissg' in 0 1) 
       Graphs: "$rootslct/graphs/v3/pt$par-af$aff-cf/eigval`usemissg'-$waglvl-cf.eps" (where `usemissg' in 0 1) */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-cf-multiheck.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf-multiheck.do
global waglvl = "frmunowage"
* do $dp/translog-selct-2stp-cf-multiheck.do
    /* Estimates Max Likelihood translog cost shares and elasticities under selection */
    /* INPUT   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf.dta" 
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_b.dta" 
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/byreg/probit`r2dg'_b.dta" 
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/byreg/sure2stp`r2dg'_e.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3ml/pt$par-af$aff-$waglvl-cf/multiheck`usemissg'_`type'.dta" (where `usemissg' in 0 1 and `type' in b se e)
               "$rootslct/estmat/v3ml/pt$par-af$aff-$waglvl-cf/multiheck`usemissg'/negsharcnt`usemissg'_ml_tbl.dta"
               "$rootslct/estmat/v3ml/pt$par-af$aff-$waglvl-cf/multiheck`usemissg'/elastsum`usemissg'_ml_tbl.dta"
               "$rootslct/estmat/v3ml/pt$par-af$aff-$waglvl-cf/multiheck`usemissg'/negeivalcnt`usemissg'_ml_tbl.dta"
               "$rootslct/estmat/v3ml/pt$par-af$aff-$waglvl-cf/multiheck`usemissg'/intelast`usemissg'_ml_b.dta"
               "$rootslct/estmat/v3ml/pt$par-af$aff-$waglvl-cf/multiheck`usemissg'/extelast`usemissg'_ml_b.dta"
               "$rootslct/estmat/v3ml/pt$par-af$aff-$waglvl-cf/multiheck`usemissg'/totelast`usemissg'_ml_b.dta"
               "$rootslct/estmat/v3ml/pt$par-af$aff-$waglvl-cf/multiheck`usemissg'/vce`usemissg'_ml_tbl.dta"
               "$rootslct/estmat/v3ml/pt$par-af$aff-$waglvl-cf/multiheck`usemissg'/tmat`usemissg'_ml_tbl.dta"
               "$rootslct/estmat/v3ml/pt$par-af$aff-$waglvl-cf/multiheck`usemissg'/zetamat`usemissg'_ml_tbl.dta"
               "$rootslct/estmat/v3ml/pt$par-af$aff-$waglvl-cf/multiheck`usemissg'/coefmat`usemissg'_ml_tbl.dta"
               "$rootslct/estmat/v3ml/pt$par-af$aff-$waglvl-cf/multiheck`usemissg'/semat`usemissg'_ml_tbl.dta"
               "$rootslct/estmat/v3ml/pt$par-af$aff-$waglvl-cf/multiheck`usemissg'/xmrmat`usemissg'_ml_tbl.dta" 
       TeX:    "$rootslct/tex/v3ml/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_ml.tex"
               "$rootslct/tex/v3ml/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_missg_ml.tex"
               "$rootslct/tex/v3ml/pt$par-af$aff-$waglvl-cf/corrT_translog`usemissg'_ml.tex"
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-multiheck.log" */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-cf-nonparam.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf-nonparam.do
global waglvl = "frmunowage"
    do $dp/translog-selct-2stp-cf-nonparam.do
    /* Estimates translog cost shares and elasticities under selection in a non-parametric two-step approach (Das, Newey, Vella 2003) */
    /* INPUT   "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-2000-translog-$waglvl-pt$par-af$aff.dta"
               "$rootslct/Xdata/mvprobit-outwfdi-ustan-2000-$waglvl-pt$par-af$aff.dta" 
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-costothr-$waglvl-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-wwlocvars-pt$par-af$aff.dta" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam.dta"
               "$rootslct/Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-nonparam.dta"
       Tables: "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/byreg/selreg`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e r)
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1 and `type' in b se e)
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negsharcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'_tbl.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/vce`usemissg'_tbl.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta" 
       TeX:    "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'.tex"
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_missg.tex"
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/corrT_translog`usemissg'.tex"
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-nonparam.log" */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-bstrap-cf-nonparam.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-bstrap-cf-nonparam.do
global waglvl = "frmunowage"
    do $dp/translog-selct-2stp-bstrap-cf-nonparam.do
    /* Bootstraps the estimates of translog cost shares and elasticities under selection from two-step approach */
    /* INPUT   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1)
       Log:    "$rootslct/logs/translog-selct-bstrap-pt$par-af$aff-$waglvl-nonparam.log" */

global waglvl = "frmowwwage"
* do $dp/tab-estmat-selct-cf-nonparam.do
global waglvl = "frmubswage"
* do $dp/tab-estmat-selct-cf-nonparam.do
global waglvl = "frmunowage"
* do $dp/tab-estmat-selct-cf-nonparam.do
    /* Saves TeX tables of selection and elasticity estimates with their bootstrapped standard errors, graphs kernels of eigenvalues */
    /* INPUT   "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/byreg/selreg`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1, and `type' in b se e r)
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negxhatcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/selreg_txt.tex"
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/selreg_apx1.tex"
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/selreg_apx2.tex"
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/selreg_apx3.tex"
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/translog`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/intelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/extelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/totelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/intmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/extmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/totmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/eigval`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/possharcnt`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/elastsum`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/negeivalcnt`usemissg'.tex" (where `usemissg' in 0 1) 
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/compelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/compmori`usemissg'.tex" (where `usemissg' in 0 1) 
       Graphs: "$rootslct/graphs/v3np/pt$par-af$aff-cf/eigval`usemissg'-$waglvl-cf.eps" (where `usemissg' in 0 1) */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-cf-nonparam-relaxed.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf-nonparam-relaxed.do
global waglvl = "frmunowage"
    do $dp/translog-selct-2stp-cf-nonparam-relaxed.do
    /* Estimates translog cost shares and elasticities under selection in a non-parametric two-step approach (Das, Newey, Vella 2003) */
    /* INPUT   "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-2000-translog-$waglvl-pt$par-af$aff.dta"
               "$rootslct/Xdata/mvprobit-outwfdi-ustan-2000-$waglvl-pt$par-af$aff.dta" 
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-costothr-$waglvl-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-wwlocvars-pt$par-af$aff.dta" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-relaxed.dta"
               "$rootslct/Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-nonparam-relaxed.dta"
       Tables: "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/byreg/selreg`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e r)
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1 and `type' in b se e)
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negsharcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/vce`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta" 
       TeX:    "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'.tex"
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_missg.tex"
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/corrT_translog`usemissg'.tex"
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-nonparam-relaxed.log" */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-bstrap-cf-nonparam-relaxed.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-bstrap-cf-nonparam-relaxed.do
global waglvl = "frmunowage"
    do $dp/translog-selct-2stp-bstrap-cf-nonparam-relaxed.do
    /* Bootstraps the estimates of translog cost shares and elasticities under selection from two-step approach */
    /* INPUT   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-relaxed.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1)
       Log:    "$rootslct/logs/translog-selct-bstrap-pt$par-af$aff-$waglvl-nonparam-relaxed.log" */

global waglvl = "frmowwwage"
* do $dp/tab-estmat-selct-cf-nonparam-relaxed.do
global waglvl = "frmubswage"
* do $dp/tab-estmat-selct-cf-nonparam-relaxed.do
global waglvl = "frmunowage"
* do $dp/tab-estmat-selct-cf-nonparam-relaxed.do
    /* Saves TeX tables of selection and elasticity estimates with their bootstrapped standard errors, graphs kernels of eigenvalues */
    /* INPUT   "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/byreg/selreg`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1, and `type' in b se e r)
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negxhatcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/selreg_txt.tex"
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/selreg_apx1.tex"
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/selreg_apx2.tex"
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/selreg_apx3.tex"
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/translog`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/intelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/extelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/totelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/intmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/extmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/totmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/eigval`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/possharcnt`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/elastsum`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/negeivalcnt`usemissg'.tex" (where `usemissg' in 0 1) 
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/compelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npr/pt$par-af$aff-$waglvl-cf/compmori`usemissg'.tex" (where `usemissg' in 0 1) 
       Graphs: "$rootslct/graphs/v3npr/pt$par-af$aff-cf/eigval`usemissg'-$waglvl-cf.eps" (where `usemissg' in 0 1) */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-cf-semiparam.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf-semiparam.do
global waglvl = "frmunowage"
* do $dp/translog-selct-2stp-cf-semiparam.do
    /* Estimates translog cost shares and elasticities under selection in a non-parametric two-step approach (Das, Newey, Vella 2003) */
    /* INPUT   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf.dta" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-semiparam.dta"
               "$rootslct/Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-semiparam.dta"
       Tables: "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/byreg/dprobit`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e r)
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1 and `type' in b se e)
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negsharcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'_tbl.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/vce`usemissg'_tbl.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta" 
       TeX:    "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'.tex"
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_missg.tex"
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/corrT_translog`usemissg'.tex"
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-semiparam.log" */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-bstrap-cf-semiparam.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-bstrap-cf-semiparam.do
global waglvl = "frmunowage"
* do $dp/translog-selct-2stp-bstrap-cf-semiparam.do
    /* Bootstraps the estimates of translog cost shares and elasticities under selection from two-step approach */
    /* INPUT   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-semiparam.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1)
       Log:    "$rootslct/logs/translog-selct-bstrap-pt$par-af$aff-$waglvl-semiparam.log" */

global waglvl = "frmowwwage"
* do $dp/tab-estmat-selct-cf-semiparam.do
global waglvl = "frmubswage"
* do $dp/tab-estmat-selct-cf-semiparam.do
global waglvl = "frmunowage"
* do $dp/tab-estmat-selct-cf-semiparam.do
    /* Saves TeX tables of selection and elasticity estimates with their bootstrapped standard errors, graphs kernels of eigenvalues */
    /* INPUT   "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/byreg/selreg`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1, and `type' in b se e r)
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negxhatcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/dprobit_txt.tex"
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/dprobit_apx1.tex"
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/dprobit_apx2.tex"
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/dprobit_apx3.tex"
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/translog`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/intelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/extelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/totelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/intmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/extmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/totmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/eigval`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/possharcnt`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/elastsum`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/negeivalcnt`usemissg'.tex" (where `usemissg' in 0 1) 
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/compelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3sp/pt$par-af$aff-$waglvl-cf/compmori`usemissg'.tex" (where `usemissg' in 0 1) 
       Graphs: "$rootslct/graphs/v3sp/pt$par-af$aff-cf/eigval`usemissg'-$waglvl-cf.eps" (where `usemissg' in 0 1) */

global waglvl = "frmowwwage"
* do $dp/tab-sample-selct-cf.do
global waglvl = "frmubswage"
* do $dp/tab-sample-selct-cf.do
global waglvl = "frmunowage"
* do $dp/tab-sample-selct-cf.do
    /* Saves TeX tables of sample statistics */
    /* INPUT   "$rootslct/tex/`path'/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_missg_tbl" (where `path' in v3 v3np, and `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/`path'/pt$par-af$aff-$waglvl-cf/summ.tex" (where `path' in v3 v3np, and `usemissg' in 0 1)
               "$rootslct/tex/`path'/pt$par-af$aff-$waglvl-cf/summmeans.tex" (where `path' in v3 v3np, and `usemissg' in 0 1) */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-spectests-cf.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-spectests-cf.do
global waglvl = "frmunowage"
* do $dp/translog-selct-2stp-spectests-cf.do
    /* Runs specification tests for translog cost function estimation under two-step approach */
    /* INPUT   "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/byreg/probit-zgamma-$waglvl-pt$par-af$aff.dta" 
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/byreg/translog`usemissg'-res-$waglvl-pt$par-af$aff.dta" */
    /* OUTPUT
       Data:   none 
       Tables: "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/byreg/ttzgamma.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/byreg/ttpresabs.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/byreg/ttepsi.dta"
       Log:    "$rootslct/logs/translog-selct-spectest-$waglvl-pt$par-af$aff.log" */

global waglvl = "frmowwwage" /* (`wagabr' oww) */
* do $dp/translog-selct-2stp-elasticities-cf.do
global waglvl = "frmubswage" /* (`wagabr' ubs) */
* do $dp/translog-selct-2stp-elasticities-cf.do
global waglvl = "frmunowage" /* (`wagabr' uno) */
* do $dp/translog-selct-2stp-elasticities-cf.do
    /* Saves tables of elasticity point estimates */
    /* INPUT   "$rootslct/estmat/v3/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/translog`usemissg'_b_tbl.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/elast`usemissg'/elast`elsttyp'`usemissg'`wagabr'_tbl.dta" (where `usemissg' in 0 1 and `elsttyp' in Int Ext Tot, )
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/elast`usemissg'/eigenval`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/elast`usemissg'/aumat`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/elast`usemissg'/mori`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3/pt$par-af$aff-$waglvl-cf/elast`usemissg'/tfmori`elsttyp'`usemissg'`wagabr'_tbl.dta"
       Log:    "$rootslct/logs/translog-selct-elasticities-$waglvl-pt$par-af$aff-cf.log" */

global waglvl = "frmowwwage" /* (`wagabr' oww) */
* do $dp/translog-selct-2stp-elasticities-cf-nonparam.do
global waglvl = "frmubswage" /* (`wagabr' ubs) */
* do $dp/translog-selct-2stp-elasticities-cf-nonparam.do
global waglvl = "frmunowage" /* (`wagabr' uno) */
* do $dp/translog-selct-2stp-elasticities-cf-nonparam.do
    /* Saves tables of elasticity point estimates */
    /* INPUT   "$rootslct/estmat/v3np/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3np/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/translog`usemissg'_b_tbl.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/elast`usemissg'/elast`elsttyp'`usemissg'`wagabr'_tbl.dta" (where `usemissg' in 0 1 and `elsttyp' in Int Ext Tot, )
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/elast`usemissg'/eigenval`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/elast`usemissg'/aumat`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/elast`usemissg'/mori`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3np/pt$par-af$aff-$waglvl-cf/elast`usemissg'/tfmori`elsttyp'`usemissg'`wagabr'_tbl.dta"
       Log:    "$rootslct/logs/translog-selct-elasticities-$waglvl-pt$par-af$aff-cf.log" */

global waglvl = "frmowwwage" /* (`wagabr' oww) */
* do $dp/translog-selct-2stp-elasticities-cf-nonparam-relaxed.do
global waglvl = "frmubswage" /* (`wagabr' ubs) */
* do $dp/translog-selct-2stp-elasticities-cf-nonparam-relaxed.do
global waglvl = "frmunowage" /* (`wagabr' uno) */
* do $dp/translog-selct-2stp-elasticities-cf-nonparam-relaxed.do
    /* Saves tables of elasticity point estimates */
    /* INPUT   "$rootslct/estmat/v3npr/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npr/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/translog`usemissg'_b_tbl.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/elast`usemissg'/elast`elsttyp'`usemissg'`wagabr'_tbl.dta" (where `usemissg' in 0 1 and `elsttyp' in Int Ext Tot, )
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/elast`usemissg'/eigenval`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/elast`usemissg'/aumat`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/elast`usemissg'/mori`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3npr/pt$par-af$aff-$waglvl-cf/elast`usemissg'/tfmori`elsttyp'`usemissg'`wagabr'_tbl.dta"
       Log:    "$rootslct/logs/translog-selct-elasticities-$waglvl-pt$par-af$aff-cf.log" */

global waglvl = "frmowwwage" /* (`wagabr' oww) */
* do $dp/translog-selct-2stp-elasticities-cf-semiparam.do
global waglvl = "frmubswage" /* (`wagabr' ubs) */
* do $dp/translog-selct-2stp-elasticities-cf-semiparam.do
global waglvl = "frmunowage" /* (`wagabr' uno) */
* do $dp/translog-selct-2stp-elasticities-cf-semiparam.do
    /* Saves tables of elasticity point estimates */
    /* INPUT   "$rootslct/estmat/v3sp/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3sp/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/translog`usemissg'_b_tbl.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/elast`usemissg'/elast`elsttyp'`usemissg'`wagabr'_tbl.dta" (where `usemissg' in 0 1 and `elsttyp' in Int Ext Tot, )
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/elast`usemissg'/eigenval`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/elast`usemissg'/aumat`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/elast`usemissg'/mori`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3sp/pt$par-af$aff-$waglvl-cf/elast`usemissg'/tfmori`elsttyp'`usemissg'`wagabr'_tbl.dta"
       Log:    "$rootslct/logs/translog-selct-elasticities-$waglvl-pt$par-af$aff-cf.log" */

global waglvl = ""
* do $dp/tab-estmat-selct-eigvalcomp-cf.do
    /* Saves TeX comparison table on eigenvalues across wagelvl types */
    /* INPUT   "$rootslct/tex/v3/pt$par-af$aff-`waglvl'-cf/eigval`usemissg'_tbl.dta" (where `waglvl' in frmowwwage frmunowage, and `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3/eigvalcomp/eigvalcomp`usemissg'pt${par}af${aff}.tex" (where `usemissg' in 0 1) */

global waglvl = ""
* do $dp/tab-estmat-selct-eigvalcomp-cf-nonparam.do
    /* Saves TeX comparison table on eigenvalues across wagelvl types */
    /* INPUT   "$rootslct/tex/v3np/pt$par-af$aff-`waglvl'-cf/eigval`usemissg'_tbl.dta" (where `waglvl' in frmowwwage frmunowage, and `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3np/eigvalcomp/eigvalcomp`usemissg'pt${par}af${aff}.tex" (where `usemissg' in 0 1) */

global waglvl = ""
* do $dp/tab-estmat-selct-eigvalcomp-cf-nonparam-relaxed.do
    /* Saves TeX comparison table on eigenvalues across wagelvl types */
    /* INPUT   "$rootslct/tex/v3npr/pt$par-af$aff-`waglvl'-cf/eigval`usemissg'_tbl.dta" (where `waglvl' in frmowwwage frmunowage, and `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3npr/eigvalcomp/eigvalcomp`usemissg'pt${par}af${aff}.tex" (where `usemissg' in 0 1) */

global waglvl = ""
* do $dp/tab-estmat-selct-eigvalcomp-cf-semiparam.do
    /* Saves TeX comparison table on eigenvalues across wagelvl types */
    /* INPUT   "$rootslct/tex/v3sp/pt$par-af$aff-`waglvl'-cf/eigval`usemissg'_tbl.dta" (where `waglvl' in frmowwwage frmunowage, and `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3sp/eigvalcomp/eigvalcomp`usemissg'pt${par}af${aff}.tex" (where `usemissg' in 0 1) */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-cf-nonparam-relaxed-graph.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf-nonparam-relaxed-graph.do
global waglvl = "frmunowage"
* do $dp/translog-selct-2stp-cf-nonparam-relaxed-graph.do
    /* Graphs the marginal effects of wages on selection and labor demand from nonparametric estimation */
    /* INPUT   "$rootslct/Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-nonparam.dta" */
    /* OUTPUT
       Graphs: "$rootslct/graphs/v3npr/pt$par-af$aff-cf/dpsc`r2dg'dw`w2dg'-ci.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
               "$rootslct/graphs/v3npr/pt$par-af$aff-cf/dpsc`r2dg'dw`w2dg'.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
               "$rootslct/graphs/v3npr/pt$par-af$aff-cf/dy`r2dg'dps`w2dg'-ci.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
               "$rootslct/graphs/v3npr/pt$par-af$aff-cf/dy`r2dg'dps`w2dg'.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-nonparam-relaxed-graph.log" */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-cf-semiparam-graph.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf-semiparam-graph.do
global waglvl = "frmunowage"
* do $dp/translog-selct-2stp-cf-semiparam-graph.do
    /* Graphs the marginal effects of wages on selection and labor demand from semiparametric estimation */
    /* INPUT   "$rootslct/Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-semiparam.dta" */
    /* OUTPUT
       Graphs: "$rootslct/graphs/v3sp/pt$par-af$aff-cf/dpsc`r2dg'dw`w2dg'-ci.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
               "$rootslct/graphs/v3sp/pt$par-af$aff-cf/dpsc`r2dg'dw`w2dg'.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
               "$rootslct/graphs/v3sp/pt$par-af$aff-cf/dx`r2dg'dps`w2dg'-ci.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
               "$rootslct/graphs/v3sp/pt$par-af$aff-cf/dx`r2dg'dps`w2dg'.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-semiparam-graph.log" */

global reglist = "hm np"
global waglvl = "frmowwwage"
* do $dp/tab-estmat-translog-comp-cf.do
global reglist = ""
global waglvl = "frmubswage"
* do $dp/tab-estmat-translog-comp-cf.do
global reglist = "hm np npr"
global waglvl = "frmunowage"
* do $dp/tab-estmat-translog-comp-cf.do
    /* Saves joint translog tables for Heckman and nonparametric regressions */
    /* INPUT   "$rootslct/tex/v3`ext'/pt$par-af$aff-$waglvl-cf/`elstld'elast`usemissg'_tbl.dta" (where `elstld' in int ext tot, and `usemissg' in 1 2) 
               "$rootslct/estmat/v3`ext'/pt$par-af$aff-$waglvl-cf/translog`usemissg'/eigval`usemissg'_tbl.dta" (where `ext' in "" and "np" and `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/cmptotelastw.tex"
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/cmpextelastw.tex"
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/cmpintelastw.tex"
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/cmpintelasty.tex"
               "$rootslct/tex/v3np/pt$par-af$aff-$waglvl-cf/translogcmp`usemissg'" (where `usemissg' in 0 1) */


* 3. REGRESSIONS ON POOLED GERMAN DATA OVER ALL YEARS FOR SELECTION PAPER (%44)
*------------------------------------------------------------------------------

global yrdiff 2  /* Decision lag between selection and production */
global addlmne "indwest_par_${yrdiff}yrlg"
global addlsec "union_${yrdiff}yrlg imp_CEE_now exp_CEE_now impinp_CEE_now imp_DEV_now exp_DEV_now impinp_DEV_now imp_OIN_now exp_OIN_now impinp_OIN_now imp_WEU_now exp_WEU_now impinp_WEU_now"

global dp "$rootdo/%stata/%44selct-ger-reg-fs"

    do $dp/#bemfiles-allyrs.do
    /* Makes DIREK-USTAN data comparable to IUI data */
    /* INPUT   "$root/Xmatch/affils-fdiall-ustan-96-01-eur-03mar2006.dta"
               "$root/Xustan/ustan-compl-03mar2006.dta" */
    /* DO      "$dpref/#variable-creation-direk.do"
               "$dpref/#variable-creation-ustan.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/affils-fdi-ustan-allyrs-plaineur.dta"
       Log:    "$rootslct/logs/bemfiles-ger.log" */

    do $dp/#reg-pop-pattern-ger-allyrs.do
    /* Prepares patterns of regional presence for estimation (makes no summary statistics) */
    /* INPUT   "$root/Xdata/affils-outwfdi96-01-eur-03mar2006.dta"
               "$root/conc/fdi-iso-country.dta"
               "$root/conc/cntry2bemgrp.dta"
               "$root/conc/sector-conc-nace.dta"
               "$root/conc/secfix.csv"
               "$root/conc/sector-conc-bem.dta"
               "$root/conc/sector-conc-aggbem.dta" */
    /* DO      "$dpref/#sector-definitions.do"
               "$dpref/#sector-country-resetting.do"
               "$root/conc/secbem.do"
               "$root/conc/sec7ltr.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff-allyrs.dta"
       Log:    "logs/reg-pop-pattern-ger-pt$par-af$aff-allyrs.log" */
       
    do $dp/prep-parent-hostcntry-data-selct-allyrs.do
    /* Prepares parent-host country level data */
    /* INPUT   "$rootslct/Xdata/affils-fdi-ustan-allyrs-plaineur.dta"
               "$root/conc/sector-conc-nace.dta"
               "$root/conc/cntry2bemgrp.dta"
               "$root/conc/secfix.csv"
               "$root/conc/sector-conc-bem.dta"
               "$root/conc/sector-conc-aggbem.dta" */
    /* DO      "$dpref/#sector-definitions.do"
               "$dpref/#sector-country-resetting.do"
               "$root/conc/secbem.do"
               "$root/conc/sec7ltr.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff-allyrs.dta"
       Log:    "$rootslct/logs/prep-parent-hostcntry-data-selct-pt$par-af$aff-allyrs.log" */

global waglvl = "frmowwwage"
    do $dp/prep-mvprobit-med-wagediff-allyrs.do
global waglvl = "frmubswage"
* do $dp/prep-mvprobit-med-wagediff-allyrs.do
global waglvl = "frmunowage"
    do $dp/prep-mvprobit-med-wagediff-allyrs.do
    /* Prepares parent-region level data for (mv)probit estimates (years 1998 1999 2000 2001)*/
    /* INPUT   "$rootslct/Xdata/ustan-compl-plaineur.dta"
               "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff-allyrs.dta"
               "$root/Xmatch/affils-fdiall-ustan-96-01-eur-03mar2006.dta"
               "$root/countries/extdata-deflated.dta"
               "$root/wages/destatis-gearn-defl.dta"
               "$root/wages/owwdata-country-`year'.dta" (where `year' in 1996 1997 1998 1999)
               "$root/wages/ubs-data-1996-2001-defl-interpolated.dta"
               "$root/wages/unido-wages-defl-1996-2001.dta"
               "$root/wages/swewages.dta"
               "$root/wages/union_sec_bem.dta"
               "$root/trade/ger-impinp-exp-secbem-ctrygrp-2000.dta"
               "$root/conc/cntry2bemgrp.dta" 
               "$root/conc/fdi-iso-country.dta"
               "$root/conc/nace2bem.dta"
               "$root/conc/sector-conc-nace.dta"
               "$root/conc/sector-conc-bem.dta" */
    /* DO      "$dpref/#wage-diff-$waglvl.do"
               "$dpref/#translog-owwwages.do"
               "$dpref/#translog-ubswages.do"
               "$dpref/#translog-unowages.do"
               "$dpref/#parinfo-probit.do"
               "$dpref/#addlvars.do"
               "$root/conc/secbem.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mvprobit-outwfdi-ustan-`tlogyear'd$yrdiff-$waglvl-pt$par-af$aff.dta" (where `tlogyear' in 1998 1999 2000 2001)
               "$rootslct/tex/desc/wagediffs/diffsger`yr'd$yrdiff-$waglvl.dta" (where `yr' in 98 99 00 01)
       Log:    "$rootslct/logs/mvprobit-prepare-selct-$waglvl-pt$par-af$aff-allyrs.log" */

global waglvl = "frmowwwage"
    do $dp/prep-translog-fdidata-allyrs.do
global waglvl = "frmubswage"
* do $dp/prep-translog-fdidata-allyrs.do
global waglvl = "frmunowage"
    do $dp/prep-translog-fdidata-allyrs.do
    /* Prepares parent-host country level data for Translog regressions */
    /* INPUT   "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff-allyrs.dta"
               "$root/wages/destatis-gearn-defl.dta"
               "$root/wages/owwdata-country-`year'.dta" (where `yr' in 1996 1997 1998 1999)
               "$root/wages/ubs-data-1996-2001-defl-interpolated.dta"
               "$root/wages/unido-wages-defl-1996-2001.dta"
               "$root/wages/swewages.dta"
               "$root/conc/fdi-iso-country.dta"
               "$root/conc/cntry2bemgrp.dta" 
               "$root/conc/sector-conc-nace.dta"
               "$root/conc/sector-conc-bem.dta" */
    /* DO      "$dpref/#translog-owwwages.do"
               "$dpref/#translog-ubswages.do"
               "$dpref/#translog-unowages.do"
               "$dpref/#translog-yearselect-wages.do"
               "$dpref/#translog-avgswe-wages.do"
               "$root/conc/secbem.do" */
    /* OUTPUT
       Data:   "$rootslct/tex/desc/pt$par-af$aff/employment-aggregates-`year'.dta" (where `year' in 1997 1998 1999 2001)
               "$rootslct/Xdata/mneid-outwfdi-ustan-`year'-translog-$waglvl-pt$par-af$aff.dta" (where `year' in 1997 1998 1999 2001)
       Log:    "$rootslct/logs/prep-translog-fdi-data-$waglvl-pt$par-af$aff-allyrs.log" */

global method "impfillin"
    do $dp/prep-vars-others-allyrs.do
    /* Prepares location-specific variables as competitors' exposure */
    /* INPUT   "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff-allyrs.dta"
               "$root/trade/mkt-access-$method-`year'.dta" (where `year' in 1997 1998 1999)
               "$root/countries/barro-lee-99-pwt-iso.dta"
               "$root/countries/extdata-deflated.dta" 
               "$root/countries/dist-deu.dta"
               "$root/conc/fdi-iso-country.dta"
               "$root/conc/cntry2bemgrp.dta"
               "$root/conc/direk-cntrylist.csv" */
    /* DO      "$dp/#wdi-external.do"
               "$root/conc/land.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-outwfdi-ustan-`year'-locvars-pt$par-af$aff.dta" (where `year' in 1997 1998 1999)
               "$rootslct/Xdata/mneid-outwfdi-ustan-`year'-wwlocvars-pt$par-af$aff.dta" (where `year' in 1997 1998 1999)
       Log:    "$rootslct/logs/prep-vars-others-pt$par-af$aff-allyrs.log" */

global waglvl = "frmowwwage"
    do $dp/prep-costs-others-allyrs.do
global waglvl = "frmubswage"
* do $dp/prep-costs-others-allyrs.do
global waglvl = "frmunowage"
    do $dp/prep-costs-others-allyrs.do
    /* Prepares competitors' wage and non-wage variables */
    /* INPUT   "$rootslct/Xdata/mneid-outwfdi-ustan-`year'-translog-$waglvl-pt$par-af$aff.dta" (where `year' in 1997 1998 1999) */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-outwfdi-ustan-`year'-costothr-$waglvl-pt$par-af$aff.dta" (where `year' in 1997 1998 1999)
       Log:    "$rootslct/logs/prep-costs-others-$waglvl-pt$par-af$aff-allyrs.log" */

global waglvl = "frmowwwage"
    do $dp/make-regdata-cf-allyrs.do
global waglvl = "frmubswage"
* do $dp/make-regdata-cf-allyrs.do
global waglvl = "frmunowage"
    do $dp/make-regdata-cf-allyrs.do
    /* Combines data over all years for translog and selection */
    /* INPUT   "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff-allyrs.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-`years'-translog-$waglvl-pt$par-af$aff.dta" (where years in 1998 1999 2000 2001)
               "$rootslct/Xdata/mvprobit-outwfdi-ustan-`years'd$yrdiff-$waglvl-pt$par-af$aff.dta" (where years in 1998 1999 2000 2001)
               "$rootslct/Xdata/mneid-outwfdi-ustan-`years'-costothr-$waglvl-pt$par-af$aff.dta" (where years in 1996 1997 1998 1999)
               "$rootslct/Xdata/mneid-outwfdi-ustan-`years'-wwlocvars-pt$par-af$aff.dta" (where years in 1996 1997 1998 1999) */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf.dta" 
       Log:    "$rootslct/logs/make-regdata-cf-allyrs.log" */

global howmany "1"
global waglvl = "frmowwwage"
    do $dp/translog-selct-2stp-cf-allyrs.do
global howmany "1"
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf-allyrs.do
global howmany "0 1 2"
global waglvl = "frmunowage"
    do $dp/translog-selct-2stp-cf-allyrs.do
    /* Estimates, on full sample (all years), translog cost shares and elasticities under selection in a two-step approach */
    /* INPUT   "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf.dta" */
    /* DO      "$dp/!varsets.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf.dta" 
       Tables: "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/byreg/dprobit`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e r)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/byreg/probit`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/byreg/sure2stp`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1 and `type' in b se e)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negsharcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/vce`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta" 
       TeX:    "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'.tex"
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_missg.tex"
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/corrT_translog`usemissg'.tex"
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-allyrs.log" */

global howmany "1"
global waglvl = "frmowwwage"
    do $dp/translog-selct-2stp-bstrap-cf-allyrs.do
global howmany "1"
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-bstrap-cf-allyrs.do
global howmany "0 1 2"
global waglvl = "frmunowage"
    do $dp/translog-selct-2stp-bstrap-cf-allyrs.do
    /* Bootstraps the estimates of translog cost shares and elasticities under selection from two-step approach */
    /* INPUT   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-allyrs.dta" */
    /* DO      "$dp/!varsets.do" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1)
       Log:    "$rootslct/logs/translog-selct-bstrap-pt$par-af$aff-$waglvl-allyrs.log" */

global howmany "1"
global waglvl = "frmowwwage"
* do $dp/tab-estmat-selct-cf-allyrs.do
global howmany "1"
global waglvl = "frmubswage"
* do $dp/tab-estmat-selct-cf-allyrs.do
global howmany "0 1 2"
global waglvl = "frmunowage"
* do $dp/tab-estmat-selct-cf-allyrs.do
    /* Saves TeX tables of selection and elasticity estimates with their bootstrapped standard errors, graphs kernels of eigenvalues */
    /* INPUT   "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/byreg/probit`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/byreg/dprobit`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1, and `type' in b se e r)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negxhatcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/sunkcost.tex"
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/probit_txt.tex"
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/probit_apx1.tex"
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/probit_apx2.tex"
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/probit_apx3.tex"
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/dprobit_txt.tex"
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/dprobit_apx1.tex"
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/dprobit_apx2.tex"
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/dprobit_apx3.tex"
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/intelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/extelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/totelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/intmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/extmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/totmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/eigval`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/possharcnt`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/elastsum`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/negeivalcnt`usemissg'.tex" (where `usemissg' in 0 1) 
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/compelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fs/pt$par-af$aff-$waglvl-cf/compmori`usemissg'.tex" (where `usemissg' in 0 1) 
       Graphs: "$rootslct/graphs/v3fs/pt$par-af$aff-cf/eigval`usemissg'-$waglvl-cf.eps" (where `usemissg' in 0 1) */
global howmany "1"

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-cf-allyrs-ar1.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf-allyrs-ar1.do
global waglvl = "frmunowage"
* do $dp/translog-selct-2stp-cf-allyrs-ar1.do
    /* Estimates, on full sample (all years), translog cost shares and elasticities under selection in a two-step approach */
    /* INPUT   "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf.dta" */
    /* DO      "$dp/!varsets.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-allyrs-ar1.dta" 
       Tables: "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/byreg/dprobit`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e r)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/byreg/probit`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/byreg/sure2stp`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1 and `type' in b se e)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negsharcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta"
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta"
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta"
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/vce`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta" 
       TeX:    "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'.tex"
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_missg.tex"
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/corrT_translog`usemissg'.tex"
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-allyrs-ar1.log" */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-bstrap-cf-allyrs-ar1.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-bstrap-cf-allyrs-ar1.do
global waglvl = "frmunowage"
* do $dp/translog-selct-2stp-bstrap-cf-allyrs-ar1.do
    /* Bootstraps the estimates of translog cost shares and elasticities under selection from two-step approach */
    /* INPUT   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-allyrs-ar1.dta" */
    /* DO      "$dp/!varsets.do" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1)
       Log:    "$rootslct/logs/translog-selct-bstrap-pt$par-af$aff-$waglvl-allyrs-ar1.log" */

global waglvl = "frmowwwage"
* do $dp/tab-estmat-selct-cf-allyrs-ar1.do
global waglvl = "frmubswage"
* do $dp/tab-estmat-selct-cf-allyrs-ar1.do
global waglvl = "frmunowage"
* do $dp/tab-estmat-selct-cf-allyrs-ar1.do
    /* Saves TeX tables of selection and elasticity estimates with their bootstrapped standard errors, graphs kernels of eigenvalues */
    /* INPUT   "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/byreg/probit`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/byreg/dprobit`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1, and `type' in b se e r)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negxhatcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/probit_txt.tex"
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/dprobit_txt.tex"
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/translog`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/intelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/extelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/totelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/intmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/extmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/totmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/eigval`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/possharcnt`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/elastsum`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/negeivalcnt`usemissg'.tex" (where `usemissg' in 0 1) 
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/compelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar1/pt$par-af$aff-$waglvl-cf/compmori`usemissg'.tex" (where `usemissg' in 0 1) 
       Graphs: "$rootslct/graphs/v3fsar1/pt$par-af$aff-cf/eigval`usemissg'-$waglvl-cf.eps" (where `usemissg' in 0 1) */
global howmany "1"

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-cf-allyrs-ar2.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf-allyrs-ar2.do
global waglvl = "frmunowage"
    do $dp/translog-selct-2stp-cf-allyrs-ar2.do
    /* Estimates, on full sample (all years), translog cost shares and elasticities under selection in a two-step approach */
    /* INPUT   "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf.dta" */
    /* DO      "$dp/!varsets.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-allyrs-ar2.dta" 
       Tables: "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/byreg/dprobit`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e r)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/byreg/probit`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/byreg/sure2stp`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1 and `type' in b se e)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negsharcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta"
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta"
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta"
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/vce`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta" 
       TeX:    "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'.tex"
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_missg.tex"
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/corrT_translog`usemissg'.tex"
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-allyrs-ar2.log" */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-bstrap-cf-allyrs-ar2.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-bstrap-cf-allyrs-ar2.do
global waglvl = "frmunowage"
    do $dp/translog-selct-2stp-bstrap-cf-allyrs-ar2.do
    /* Bootstraps the estimates of translog cost shares and elasticities under selection from two-step approach */
    /* INPUT   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-allyrs-ar2.dta" */
    /* DO      "$dp/!varsets.do" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1)
       Log:    "$rootslct/logs/translog-selct-bstrap-pt$par-af$aff-$waglvl-allyrs-ar2.log" */

global waglvl = "frmowwwage"
* do $dp/tab-estmat-selct-cf-allyrs-ar2.do
global waglvl = "frmubswage"
* do $dp/tab-estmat-selct-cf-allyrs-ar2.do
global waglvl = "frmunowage"
* do $dp/tab-estmat-selct-cf-allyrs-ar2.do
    /* Saves TeX tables of selection and elasticity estimates with their bootstrapped standard errors, graphs kernels of eigenvalues */
    /* INPUT   "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/byreg/probit`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/byreg/dprobit`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1, and `type' in b se e r)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negxhatcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/probit_txt.tex"
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/dprobit_txt.tex"
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/intelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/extelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/totelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/intmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/extmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/totmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/eigval`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/possharcnt`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/elastsum`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/negeivalcnt`usemissg'.tex" (where `usemissg' in 0 1) 
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/compelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3fsar2/pt$par-af$aff-$waglvl-cf/compmori`usemissg'.tex" (where `usemissg' in 0 1) 
       Graphs: "$rootslct/graphs/v3fsar2/pt$par-af$aff-cf/eigval`usemissg'-$waglvl-cf.eps" (where `usemissg' in 0 1) */
global howmany "1"

global waglvl = "frmowwwage"
    do $dp/translog-selct-2stp-cf-nonparam-allyrs.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf-nonparam-allyrs.do
global waglvl = "frmunowage"
    do $dp/translog-selct-2stp-cf-nonparam-allyrs.do
    /* Estimates translog cost shares and elasticities under selection in a non-parametric two-step approach (Das, Newey, Vella 2003) */
    /* INPUT   "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-2000-translog-$waglvl-pt$par-af$aff.dta"
               "$rootslct/Xdata/mvprobit-outwfdi-ustan-2000-$waglvl-pt$par-af$aff.dta" 
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-costothr-$waglvl-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-wwlocvars-pt$par-af$aff.dta" */
    /* DO      "$dp/!varsets-np.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-allyrs.dta"
               "$rootslct/Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-nonparam-allyrs.dta"
       Tables: "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/byreg/selreg`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e r)
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1 and `type' in b se e)
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negsharcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/vce`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta" 
       TeX:    "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'.tex"
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_missg`r2dg'.tex" (where `r2dg' in "" CE DE OI WE)
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/corrT_translog`usemissg'.tex"
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-nonparam-allyrs.log" */

global waglvl = "frmowwwage"
    do $dp/translog-selct-2stp-bstrap-cf-nonparam-allyrs.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-bstrap-cf-nonparam-allyrs.do
global waglvl = "frmunowage"
    do $dp/translog-selct-2stp-bstrap-cf-nonparam-allyrs.do
    /* Bootstraps the estimates of translog cost shares and elasticities under selection from two-step approach */
    /* INPUT   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-allyrs.dta" */
    /* DO      "$dp/!varsets-np.do" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1)
       Log:    "$rootslct/logs/translog-selct-bstrap-pt$par-af$aff-$waglvl-nonparam-allyrs.log" */

global waglvl = "frmowwwage"
* do $dp/tab-estmat-selct-cf-nonparam-allyrs.do
global waglvl = "frmubswage"
* do $dp/tab-estmat-selct-cf-nonparam-allyrs.do
global waglvl = "frmunowage"
* do $dp/tab-estmat-selct-cf-nonparam-allyrs.do
    /* Saves TeX tables of selection and elasticity estimates with their bootstrapped standard errors, graphs kernels of eigenvalues */
    /* INPUT   "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/byreg/selreg`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1, and `type' in b se e r)
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negxhatcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/selreg_txt.tex"
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/selreg_apx1.tex"
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/selreg_apx2.tex"
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/selreg_apx3.tex"
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/intelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/extelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/totelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/intmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/extmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/totmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/eigval`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/possharcnt`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/elastsum`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/negeivalcnt`usemissg'.tex" (where `usemissg' in 0 1) 
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/compelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/compmori`usemissg'.tex" (where `usemissg' in 0 1) 
       Graphs: "$rootslct/graphs/v3npfs/pt$par-af$aff-cf/eigval`usemissg'-$waglvl-cf.eps" (where `usemissg' in 0 1) */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-cf-nonparam-relaxed-allyrs.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf-nonparam-relaxed-allyrs.do
global waglvl = "frmunowage"
    do $dp/translog-selct-2stp-cf-nonparam-relaxed-allyrs.do
    /* Estimates translog cost shares and elasticities under selection in a non-parametric two-step approach (Das, Newey, Vella 2003) */
    /* INPUT   "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf.dta" */
    /* DO      "$dp/!varsets-np.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-allyrs.dta"
               "$rootslct/Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-nonparam-allyrs.dta"
       Tables: "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/byreg/selreg`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e r)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1 and `type' in b se e)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negsharcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'_tbl.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/vce`usemissg'_tbl.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta" 
       TeX:    "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'.tex"
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_missg.tex"
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/corrT_translog`usemissg'.tex"
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-nonparam-allyrs.log" */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-bstrap-cf-nonparam-relaxed-allyrs.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-bstrap-cf-nonparam-relaxed-allyrs.do
global waglvl = "frmunowage"
    do $dp/translog-selct-2stp-bstrap-cf-nonparam-relaxed-allyrs.do
    /* Bootstraps the estimates of translog cost shares and elasticities under selection from two-step approach */
    /* INPUT   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-relaxed-allyrs.dta" */
    /* DO      "$dp/!varsets-np.do" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1)
       Log:    "$rootslct/logs/translog-selct-bstrap-pt$par-af$aff-$waglvl-nonparam-relaxed-allyrs.log" */

global waglvl = "frmowwwage"
* do $dp/tab-estmat-selct-cf-nonparam-relaxed-allyrs.do
global waglvl = "frmubswage"
* do $dp/tab-estmat-selct-cf-nonparam-relaxed-allyrs.do
global waglvl = "frmunowage"
* do $dp/tab-estmat-selct-cf-nonparam-relaxed-allyrs.do
    /* Saves TeX tables of selection and elasticity estimates with their bootstrapped standard errors, graphs kernels of eigenvalues */
    /* INPUT   "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/byreg/probit`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/byreg/dprobit`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1, and `type' in b se e r)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negxhatcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/selreg_txt.tex"
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/selreg_apx1.tex"
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/selreg_apx2.tex"
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/selreg_apx3.tex"
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/intelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/extelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/totelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/intmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/extmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/totmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/eigval`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/possharcnt`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/elastsum`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/negeivalcnt`usemissg'.tex" (where `usemissg' in 0 1) 
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/compelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3nprfs/pt$par-af$aff-$waglvl-cf/compmori`usemissg'.tex" (where `usemissg' in 0 1) 
       Graphs: "$rootslct/graphs/v3nprfs/pt$par-af$aff-cf/eigval`usemissg'-$waglvl-cf.eps" (where `usemissg' in 0 1) */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-cf-semiparam-allyrs.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf-semiparam-allyrs.do
global waglvl = "frmunowage"
* do $dp/translog-selct-2stp-cf-semiparam-allyrs.do
    /* Estimates translog cost shares and elasticities under selection in a non-parametric two-step approach (Das, Newey, Vella 2003) */
    /* INPUT   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf.dta" */
    /* DO      "$dp/!varsets-sp.do" */
    /* OUTPUT
       Data:   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-semiparam-allyrs.dta"
               "$rootslct/Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-semiparam-allyrs.dta"
       Tables: "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/byreg/dprobit`r2dg'_`type'.dta" (where `r2dg' is two-digit region and `type' in b se e r)
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1 and `type' in b se e)
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negsharcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'_tbl.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'_tbl.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/vce`usemissg'_tbl.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta" 
       TeX:    "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'.tex"
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_missg`r2dg'.tex" (where `r2dg' in "" CE DE OI WE)
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/corrT_translog`usemissg'.tex"
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-semiparam-allyrs.log" */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-bstrap-cf-semiparam-allyrs.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-bstrap-cf-semiparam-allyrs.do
global waglvl = "frmunowage"
* do $dp/translog-selct-2stp-bstrap-cf-semiparam-allyrs.do
    /* Bootstraps the estimates of translog cost shares and elasticities under selection from two-step approach */
    /* INPUT   "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-semiparam-allyrs.dta" */
    /* DO      "$dp/!varsets-sp.do" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1)
       Log:    "$rootslct/logs/translog-selct-bstrap-pt$par-af$aff-$waglvl-semiparam-allyrs.log" */

global waglvl = "frmowwwage"
* do $dp/tab-estmat-selct-cf-semiparam-allyrs.do
global waglvl = "frmubswage"
* do $dp/tab-estmat-selct-cf-semiparam-allyrs.do
global waglvl = "frmunowage"
* do $dp/tab-estmat-selct-cf-semiparam-allyrs.do
    /* Saves TeX tables of selection and elasticity estimates with their bootstrapped standard errors, graphs kernels of eigenvalues */
    /* INPUT   "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/byreg/selreg`r2dg'_`type'.dta" (where `r2dg' in CE DE OI WE, and `type' in b se e r)
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/translog`usemissg'_`type'.dta" (where `usemissg' in 0 1, and `type' in b se e r)
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/intelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/extelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/totelast`usemissg'_b.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/zetamat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/semat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negxhatcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elastsum`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/negeivalcnt`usemissg'.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap.dta" (where `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/dprobit_txt.tex"
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/dprobit_apx1.tex"
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/dprobit_apx2.tex"
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/dprobit_apx3.tex"
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/intelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/extelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/totelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/intmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/extmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/totmori`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/eigval`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/possharcnt`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/elastsum`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/negeivalcnt`usemissg'.tex" (where `usemissg' in 0 1) 
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/compelast`usemissg'.tex" (where `usemissg' in 0 1)
               "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf/compmori`usemissg'.tex" (where `usemissg' in 0 1) 
       Graphs: "$rootslct/graphs/v3spfs/pt$par-af$aff-cf/eigval`usemissg'-$waglvl-cf.eps" (where `usemissg' in 0 1) */

global waglvl = "frmowwwage"
* do $dp/tab-sample-selct-cf-allyrs.do
global waglvl = "frmubswage"
* do $dp/tab-sample-selct-cf-allyrs.do
global waglvl = "frmunowage"
* do $dp/tab-sample-selct-cf-allyrs.do
    /* Saves TeX tables of sample statistics */
    /* INPUT   "$rootslct/tex/`path'/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_missg`r2dg'_tbl" (where `path' in v3fs v3npfs, `usemissg' in 0 1, and `r2dg' in "" CE DE OI WE) */
    /* DO      "$dp/!varsets.do" */
    /* OUTPUT
       TeX:    "$rootslct/tex/`path'/pt$par-af$aff-$waglvl-cf/summ.tex" (where `path' in v3fs v3npfs, and `usemissg' in 0 1)
               "$rootslct/tex/`path'/pt$par-af$aff-$waglvl-cf/summmeans.tex" (where `path' in v3fs v3npfs, and `usemissg' in 0 1) */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-spectests-cf-allyrs.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-spectests-cf-allyrs.do
global waglvl = "frmunowage"
* do $dp/translog-selct-2stp-spectests-cf-allyrs.do
    /* Runs specification tests for translog cost function estimation under two-step approach */
    /* INPUT   "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/byreg/probit-zgamma-$waglvl-pt$par-af$aff.dta" 
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/byreg/translog`usemissg'-res-$waglvl-pt$par-af$aff.dta" */
    /* OUTPUT
       Data:   none 
       Tables: "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/byreg/ttzgamma.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/byreg/ttpresabs.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/byreg/ttepsi.dta"
       Log:    "$rootslct/logs/translog-selct-spectest-$waglvl-pt$par-af$aff-allyrs.log" */

global waglvl = "frmowwwage" /* (`wagabr' oww) */
* do $dp/translog-selct-2stp-elasticities-cf-allyrs.do
global waglvl = "frmubswage" /* (`wagabr' ubs) */
* do $dp/translog-selct-2stp-elasticities-cf-allyrs.do
global waglvl = "frmunowage" /* (`wagabr' uno) */
* do $dp/translog-selct-2stp-elasticities-cf-allyrs.do
    /* Saves tables of elasticity point estimates */
    /* INPUT   "$rootslct/estmat/v3fs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3fs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/translog`usemissg'_b_tbl.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/elast`elsttyp'`usemissg'`wagabr'_tbl.dta" (where `usemissg' in 0 1 and `elsttyp' in Int Ext Tot, )
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/eigenval`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/aumat`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/mori`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3fs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/tfmori`elsttyp'`usemissg'`wagabr'_tbl.dta"
       Log:    "$rootslct/logs/translog-selct-elasticities-$waglvl-pt$par-af$aff-cf-allyrs.log" */

global waglvl = "frmowwwage" /* (`wagabr' oww) */
* do $dp/translog-selct-2stp-elasticities-cf-nonparam-allyrs.do
global waglvl = "frmubswage" /* (`wagabr' ubs) */
* do $dp/translog-selct-2stp-elasticities-cf-nonparam-allyrs.do
global waglvl = "frmunowage" /* (`wagabr' uno) */
* do $dp/translog-selct-2stp-elasticities-cf-nonparam-allyrs.do
    /* Saves tables of elasticity point estimates */
    /* INPUT   "$rootslct/estmat/v3npfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3npfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/translog`usemissg'_b_tbl.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/elast`elsttyp'`usemissg'`wagabr'_tbl.dta" (where `usemissg' in 0 1 and `elsttyp' in Int Ext Tot, )
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/eigenval`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/aumat`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/mori`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3npfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/tfmori`elsttyp'`usemissg'`wagabr'_tbl.dta"
       Log:    "$rootslct/logs/translog-selct-elasticities-$waglvl-pt$par-af$aff-cf-allyrs.log" */

global waglvl = "frmowwwage" /* (`wagabr' oww) */
* do $dp/translog-selct-2stp-elasticities-cf-nonparam-relaxed-allyrs.do
global waglvl = "frmubswage" /* (`wagabr' ubs) */
* do $dp/translog-selct-2stp-elasticities-cf-nonparam-relaxed-allyrs.do
global waglvl = "frmunowage" /* (`wagabr' uno) */
* do $dp/translog-selct-2stp-elasticities-cf-nonparam-relaxed-allyrs.do
    /* Saves tables of elasticity point estimates */
    /* INPUT   "$rootslct/estmat/v3nprfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/translog`usemissg'_b_tbl.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/elast`elsttyp'`usemissg'`wagabr'_tbl.dta" (where `usemissg' in 0 1 and `elsttyp' in Int Ext Tot, )
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/eigenval`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/aumat`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/mori`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3nprfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/tfmori`elsttyp'`usemissg'`wagabr'_tbl.dta"
       Log:    "$rootslct/logs/translog-selct-elasticities-$waglvl-pt$par-af$aff-cf-allyrs.log" */

global waglvl = "frmowwwage" /* (`wagabr' oww) */
* do $dp/translog-selct-2stp-elasticities-cf-semiparam-allyrs.do
global waglvl = "frmubswage" /* (`wagabr' ubs) */
* do $dp/translog-selct-2stp-elasticities-cf-semiparam-allyrs.do
global waglvl = "frmunowage" /* (`wagabr' uno) */
* do $dp/translog-selct-2stp-elasticities-cf-semiparam-allyrs.do
    /* Saves tables of elasticity point estimates */
    /* INPUT   "$rootslct/estmat/v3spfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/coefmat`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/estmat/v3spfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/xmrmat`usemissg'_tbl.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/translog`usemissg'_b_tbl.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg'/tmat`usemissg'_tbl.dta" */
    /* OUTPUT
       Tables: "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/elast`elsttyp'`usemissg'`wagabr'_tbl.dta" (where `usemissg' in 0 1 and `elsttyp' in Int Ext Tot, )
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/eigenval`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/aumat`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/mori`elsttyp'`usemissg'`wagabr'_tbl.dta"
               "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'/tfmori`elsttyp'`usemissg'`wagabr'_tbl.dta"
       Log:    "$rootslct/logs/translog-selct-elasticities-$waglvl-pt$par-af$aff-cf-allyrs.log" */

global waglvl = ""
* do $dp/tab-estmat-selct-eigvalcomp-cf-allyrs.do
    /* Saves TeX comparison table on eigenvalues across wagelvl types */
    /* INPUT   "$rootslct/tex/v3fs/pt$par-af$aff-`waglvl'-cf/eigval`usemissg'_tbl.dta" (where `waglvl' in frmowwwage frmubswage frmunowage, and `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3fs/eigvalcomp/eigvalcomp`usemissg'pt${par}af${aff}.tex" (where `usemissg' in 0 1) */

global waglvl = ""
* do $dp/tab-estmat-selct-eigvalcomp-cf-nonparam-allyrs.do
    /* Saves TeX comparison table on eigenvalues across wagelvl types */
    /* INPUT   "$rootslct/tex/v3npfs/pt$par-af$aff-`waglvl'-cf/eigval`usemissg'_tbl.dta" (where `waglvl' in frmowwwage frmunowage, and `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3npfs/eigvalcomp/eigvalcomp`usemissg'pt${par}af${aff}.tex" (where `usemissg' in 0 1) */

global waglvl = ""
* do $dp/tab-estmat-selct-eigvalcomp-cf-nonparam-relaxed-allyrs.do
    /* Saves TeX comparison table on eigenvalues across wagelvl types */
    /* INPUT   "$rootslct/tex/v3nprfs/pt$par-af$aff-`waglvl'-cf/eigval`usemissg'_tbl.dta" (where `waglvl' in frmowwwage frmunowage, and `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3nprfs/eigvalcomp/eigvalcomp`usemissg'pt${par}af${aff}.tex" (where `usemissg' in 0 1) */

global waglvl = ""
* do $dp/tab-estmat-selct-eigvalcomp-cf-semiparam-allyrs.do
    /* Saves TeX comparison table on eigenvalues across wagelvl types */
    /* INPUT   "$rootslct/tex/v3spfs/pt$par-af$aff-`waglvl'-cf/eigval`usemissg'_tbl.dta" (where `waglvl' in frmowwwage frmunowage, and `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3spfs/eigvalcomp/eigvalcomp`usemissg'pt${par}af${aff}.tex" (where `usemissg' in 0 1) */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-cf-nonparam-relaxed-graph-allyrs.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf-nonparam-relaxed-graph-allyrs.do
global waglvl = "frmunowage"
* do $dp/translog-selct-2stp-cf-nonparam-relaxed-graph-allyrs.do
    /* Graphs the marginal effects of wages on selection and labor demand from nonparametric estimation */
    /* INPUT   "$rootslct/Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-nonparam-relaxed-allyrs.dta" */
    /* OUTPUT
       Graphs: "$rootslct/graphs/v3nprfs/pt$par-af$aff-cf/dpsc`r2dg'dw`w2dg'-ci.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
               "$rootslct/graphs/v3nprfs/pt$par-af$aff-cf/dpsc`r2dg'dw`w2dg'.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
               "$rootslct/graphs/v3nprfs/pt$par-af$aff-cf/dy`r2dg'dps`w2dg'-ci.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
               "$rootslct/graphs/v3nprfs/pt$par-af$aff-cf/dy`r2dg'dps`w2dg'.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-nonparam-relaxed-graph-allyrs.log" */

global waglvl = "frmowwwage"
* do $dp/translog-selct-2stp-cf-semiparam-graph-allyrs.do
global waglvl = "frmubswage"
* do $dp/translog-selct-2stp-cf-semiparam-graph-allyrs.do
global waglvl = "frmunowage"
* do $dp/translog-selct-2stp-cf-semiparam-graph-allyrs.do
    /* Graphs the marginal effects of wages on selection and labor demand from nonparametric estimation */
    /* INPUT   "$rootslct/Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-semiparam-allyrs.dta" */
    /* OUTPUT
       Graphs: "$rootslct/graphs/v3spfs/pt$par-af$aff-cf/dpsc`r2dg'dw`w2dg'-ci.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
               "$rootslct/graphs/v3spfs/pt$par-af$aff-cf/dpsc`r2dg'dw`w2dg'.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
               "$rootslct/graphs/v3spfs/pt$par-af$aff-cf/dy`r2dg'dps`w2dg'-ci.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
               "$rootslct/graphs/v3spfs/pt$par-af$aff-cf/dy`r2dg'dps`w2dg'.eps" (where `r2dg' and `w2dg' in HO CE DE OI WE)
       Log:    "$rootslct/logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-semiparam-graph-allyrs.log" */

global howmany "1"
global reglist = "hm np"
global waglvl = "frmowwwage"
* do $dp/tab-estmat-translog-comp-cf-allyrs.do
global howmany "1"
global reglist = "hm np"
global waglvl = "frmubswage"
* do $dp/tab-estmat-translog-comp-cf-allyrs.do
global howmany "1 0 2"
global reglist = "hm np npr sp"
global waglvl = "frmunowage"
* do $dp/tab-estmat-translog-comp-cf-allyrs.do
    /* Saves joint translog tables for Heckman and nonparametric regressions */
    /* INPUT   "$rootslct/tex/v3`ext'fs/pt$par-af$aff-$waglvl-cf/`elstld'elast`usemissg'_tbl.dta" (where `elstld' in int ext tot, and `usemissg' in 1 2) 
               "$rootslct/estmat/v3`ext'fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'/eigval`usemissg'_tbl.dta" (where `ext' in "" and "np" and `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/cmptotelastw.tex"
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/cmpextelastw.tex"
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/cmpintelastw.tex"
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/cmpintelasty.tex"
               "$rootslct/tex/v3npfs/pt$par-af$aff-$waglvl-cf/translogcmp`usemissg'" (where `usemissg' in 0 1) */
global howmany "1"


* 4. SUMMARIZE AND GRAPH GERMAN AND SWEDISH DATA AND RESULTS (%45)
*-----------------------------------------------------------------

global dp "$rootdo/%stata/%45selct-ger&swe-tab"

global waglvl = ""
* do $dp/#regagg-ger.do
    /* Regional employment aggregates, predicted home employment */
    /* INPUT   "$rootslct/Xdata/affils-fdiall-ustan-00-plaineur.dta"
               "$root/conc/cntry2bemgrp.dta" 
               "$root/conc/sector-conc-nace.dta"
               "$root/conc/fdi-iso-country.dta" */
    /* DO      "$dpref/#sector-definitions.do"
               "$dpref/#sector-country-resetting.do" */
    /* OUTPUT
       Data:   "$rootslct/tex/desc/pt$par-af$aff/employment-population-`year'.dta" (`year' in 2000)
               "$rootslct/tex/desc/pt$par-af$aff/employment-transf-population-`year'.dta" (`year' in 2000)
       Log:    "$rootslct/logs/regagg-pt$par-af$aff-ger.log" */

global waglvl = "frmunowage" /* for file reference mvprobit-outwfdi only */
* do $dp/#reg-smpl-pattern-ger.do
    /* Regional presence patterns in the sample (in contrast to the population in tex/pop/pt$par-af$aff from %40/#reg-pop-pattern-ger.do) */
    /* INPUT   "$rootslct/Xdata/affils-fdi-ustan-96&00-plaineur.dta"
               "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff.dta"
               "$rootslct/Xdata/mvprobit-outwfdi-ustan-2000-$waglvl-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-wwlocvars-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-costothr-frmowwwage-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-1996-translog-frmowwwage-pt$par-af$aff.dta"
               "$rootslct/Xdata/mneid-outwfdi-ustan-2000-translog-frmowwwage-pt$par-af$aff.dta" */
    /* OUTPUT
       TeX:    "$rootslct/tex/desc/pt$par-af$aff/summ_del_naff.tex"   
               "$rootslct/tex/desc/pt$par-af$aff/summ_del_naff96.tex"
               "$rootslct/tex/desc/pt$par-af$aff/summ_del_naff00.tex"
               "$rootslct/tex/desc/pt$par-af$aff/delnaff.tex"
               "$rootslct/tex/desc/pt$par-af$aff/pattern96.tex"
               "$rootslct/tex/desc/pt$par-af$aff/pattern00.tex"
               "$rootslct/tex/desc/pt$par-af$aff/countries_compl.tex"
               "$rootslct/tex/desc/pt$par-af$aff/countries.tex"
       Log:    "$rootslct/logs/reg-pattern-pt$par-af$aff-ger.log" */

global waglvl = ""
* do $dp/#tot-attrition-ger.do
    /* Patterns of regional presence in samples and population */
    /* INPUT   "$root/Xdata/affils-outwfdi96-01-eur-03mar2006.dta"
               "$root/Xustan/ustan-compl-03mar2006.dta" 
               "$root/Xmatch/affils-fdiall-ustan-96-01-eur-03mar2006.dta"
               "$rootslct/Xdata/affils-fdi-ustan-96&00-plaineur.dta" */
    /* OUTPUT
       Log:    "$rootslct/logs/tot-attrition-ger.log" */

global waglvl = ""
* do $dp/#comp-mat-ger-cf.do
    /* Comparison TeX tables across wage variables and foreign affiliate types */
    /* INPUT   "$rootslct/tex/v3fs/pt$par-af$aff-frmowwwage-cf/intelast`usemissg'_tbl.dta"
               "$rootslct/tex/v3fs/pt$par-af$aff-frmunowage-cf/intelast`usemissg'_tbl.dta" */
    /* OUTPUT
       TeX:    "$rootslct/tex/v3fs/compmanfowwuno`usemissg'.tex" 
       Log:    "$rootslct/logs/comp-elast-ger-cf.log" */

global waglvl = "frmowwwage"
* do $dp/#comp-elast-ger-cf.do
global waglvl = "frmunowage"
* do $dp/#comp-elast-ger-cf.do
    /* Comparison TeX tables across wage variables and foreign affiliate types */
    /* INPUT   "$rootslct/tex/`path'/pt$par-af$aff-frm`wag'wage-cf/cmp`mat'elastw_tbl" (where `mat' in int ext, `wag' in oww uno, `path' in v3np v3npfs) */
    /* OUTPUT
       TeX:    "$rootslct/tex/comp/pt$par-af$aff-cf/cmp`mat'y.tex" (where `mat' in int`wag' ext`wag', `wag' in oww uno)
       Log:    "$rootslct/logs/comp-elast-ger-cf.log" */

global sample "v3fs"
global waglvl = "frmowwwage" /* (`wagabr' oww) */
* do $dp/#counterfact-ger-cf.do
global waglvl = "frmubswage" /* (`wagabr' ubs) */
* do $dp/#counterfact-ger-cf.do
global waglvl = "frmunowage" /* (`wagabr' uno) */
* do $dp/#counterfact-ger-cf.do
    /* Counterfactual evaluations Germany */
    /* INPUT   "$rootslct/tex/desc/wagediffs/diffsger00-$waglvl.dta"
               "$rootslct/tex/desc/pt$par-af$aff/employment-transf-population-2000.dta" 
               "$rootslct/tex/$sample/pt$par-af$aff-$waglvl-cf/summ_translog`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/tex/$sample/pt$par-af$aff-$waglvl-cf/intelast`usemissg'_tbl.dta" (where `usemissg' in 0 1)
               "$rootslct/tex/$sample/pt$par-af$aff-$waglvl-cf/totelast`usemissg'_tbl.dta" (where `usemissg' in 0 1) */
    /* OUTPUT
       TeX:    "$rootslct/tex/desc/wagediffs/wdiff`wagabr'ger00.tex"
               "$rootslct/tex/desc/pt$par-af$aff/emplgerpop.tex"
               "$rootslct/tex/$sample/pt$par-af$aff-$waglvl-cf/intelastgerpop`usemissg'.tex" (`usemissg' in 0 1) 
               "$rootslct/tex/$sample/pt$par-af$aff-$waglvl-cf/totelastgerpop`usemissg'.tex" (`usemissg' in 0 1)
               "$rootslct/tex/$sample/pt$par-af$aff-$waglvl-cf/intdsplgerpop`usemissg'.tex" (`usemissg' in 0 1) 
               "$rootslct/tex/$sample/pt$par-af$aff-$waglvl-cf/totdsplgerpop`usemissg'.tex" (`usemissg' in 0 1)  
               "$rootslct/tex/$sample/pt$par-af$aff-$waglvl-cf/elastgerpop`usemissg'.tex" (`usemissg' in 0 1)
               "$rootslct/tex/$sample/pt$par-af$aff-$waglvl-cf/dsplgerpop`usemissg'.tex" (`usemissg' in 0 1)
       Log:    "$rootslct/logs/counterfact-ger-cf.log" */

global waglvl "frmunowage"
global method "impfillin"
